@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: LeastCostPathProfile_Points.cpp 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id: LeastCostPathProfile_Points.cpp 2208 2014-08-27 16:00:51Z oconrad $
  *********************************************************/
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -304,7 +304,7 @@ bool CLeastCostPathProfile_Points::Add_Point(int x, int y, CSG_Shapes *pPoints,
 
 		for( i=0; i<m_pValues->Get_Count(); i++ )
 		{
-			pPoint->Set_Value(VALUE_OFFSET + i, m_pValues->asGrid(i)->asDouble(x, y, true));
+			pPoint->Set_Value(VALUE_OFFSET + i, m_pValues->asGrid(i)->asDouble(x, y));
 		}
 
 		pLine->Get_Shape(0)->Add_Point(Point);
