@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: Interpolation_InverseDistance.cpp 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id: Interpolation_InverseDistance.cpp 2212 2014-09-01 13:29:48Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -181,7 +181,7 @@ int CInterpolation_InverseDistance::On_Parameters_Enable(CSG_Parameters *pParame
 		pParameters->Get_Parameter("WEIGHT_BANDWIDTH" )->Set_Enabled(pParameter->asInt() >= 2);	// exponential or gaussian
 	}
 
-	return( 1 );
+	return( CInterpolation::On_Parameters_Enable(pParameters, pParameter) ? 1 : 0 );
 }
 
 
@@ -244,7 +244,7 @@ inline bool CInterpolation_InverseDistance::Get_Point(int iPoint, double x, doub
 	{
 		CSG_Shape	*pPoint	= m_pShapes->Get_Shape(iPoint);
 
-		if( !pPoint )
+		if( !pPoint || pPoint->is_NoData(m_zField) )
 		{
 			return( false );
 		}
