@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: crs_base.cpp 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id: crs_base.cpp 2150 2014-06-10 14:47:45Z reklov_w $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -182,7 +182,7 @@ bool CCRS_Base::On_Before_Execution(void)
 {
 	m_Projection.Create(Parameters("CRS_PROJ4")->asString(), SG_PROJ_FMT_Proj4);
 
-	if( m_Projection.is_Okay() )
+	if( m_Projection.is_Okay() && Parameters("CRS_DIALOG") )
 	{
 		Set_User_Definition(*Parameters("CRS_DIALOG")->asParameters(), Parameters("CRS_PROJ4")->asString());
 	}
@@ -230,7 +230,10 @@ int CCRS_Base::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *
 	//-----------------------------------------------------
 	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "CRS_EPSG") )
 	{
-		Projection.Create(pParameter->asInt());
+		if (!Projection.Create(pParameter->asInt()))
+		{
+			SG_UI_Dlg_Message(_TL("Unkown EPSG Code"), _TL("WARNING"));
+		}
 	}
 
 	//-----------------------------------------------------
