@@ -78,7 +78,7 @@ CPoint_Multi_Grid_Regression::CPoint_Multi_Grid_Regression(void)
 	//-----------------------------------------------------
 	Set_Name		(_TL("Multiple Regression Analysis (Points/Grids)"));
 
-	Set_Author		(SG_T("O.Conrad (c) 2004"));
+	Set_Author		("O.Conrad (c) 2004");
 
 	Set_Description	(_TW(
 		"Linear regression analysis of point attributes with multiple grids. "
@@ -100,7 +100,7 @@ CPoint_Multi_Grid_Regression::CPoint_Multi_Grid_Regression(void)
 	);
 
 	pNode	= Parameters.Add_Shapes(
-		NULL	, "SHAPES"		, _TL("Shapes"),
+		NULL	, "POINTS"		, _TL("Points"),
 		_TL(""),
 		PARAMETER_INPUT
 	);
@@ -221,9 +221,15 @@ CPoint_Multi_Grid_Regression::CPoint_Multi_Grid_Regression(void)
 //---------------------------------------------------------
 int CPoint_Multi_Grid_Regression::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("CROSSVAL")) )
+	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "CROSSVAL") )
 	{
-		pParameters->Get_Parameter("CROSSVAL_K")->Set_Enabled(pParameter->asInt() == 3);	// k-fold
+		pParameters->Set_Enabled("CROSSVAL_K", pParameter->asInt() == 3);	// k-fold
+	}
+
+	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "METHOD") )
+	{
+		pParameters->Set_Enabled("P_IN" , pParameter->asInt() == 1 || pParameter->asInt() == 3);
+		pParameters->Set_Enabled("P_OUT", pParameter->asInt() == 2 || pParameter->asInt() == 3);
 	}
 
 	return( 0 );
@@ -244,20 +250,20 @@ bool CPoint_Multi_Grid_Regression::On_Execute(void)
 	double					P_in, P_out;
 	CSG_Strings				Names;
 	CSG_Matrix				Samples;
-	CSG_Shapes				*pShapes;
+	CSG_Shapes				*pPoints;
 	CSG_Grid				*pRegression;
 	CSG_Parameter_Grid_List	*pGrids;
 
 	//-----------------------------------------------------
-	pGrids			= Parameters("GRIDS")		->asGridList();
-	pRegression		= Parameters("REGRESSION")	->asGrid();
-	pShapes			= Parameters("SHAPES")		->asShapes();
-	iAttribute		= Parameters("ATTRIBUTE")	->asInt();
-	P_in			= Parameters("P_IN")		->asDouble() / 100.0;
-	P_out			= Parameters("P_OUT")		->asDouble() / 100.0;
+	pGrids		= Parameters("GRIDS"     )->asGridList();
+	pRegression	= Parameters("REGRESSION")->asGrid();
+	pPoints		= Parameters("POINTS"    )->asShapes();
+	iAttribute	= Parameters("ATTRIBUTE" )->asInt();
+	P_in		= Parameters("P_IN"      )->asDouble() / 100.0;
+	P_out		= Parameters("P_OUT"     )->asDouble() / 100.0;
 
 	//-----------------------------------------------------
-	if( !Get_Samples(pGrids, pShapes, iAttribute, Samples, Names) )
+	if( !Get_Samples(pGrids, pPoints, iAttribute, Samples, Names) )
 	{
 		return( false );
 	}
@@ -276,6 +282,8 @@ bool CPoint_Multi_Grid_Regression::On_Execute(void)
 
 	if( bResult == false )
 	{
+		Error_Set(_TL("regression analysis could not detect a significant predictor"));
+
 		return( false );
 	}
 
@@ -306,7 +314,7 @@ bool CPoint_Multi_Grid_Regression::On_Execute(void)
 	//-----------------------------------------------------
 	Set_Regression(pGrids, pRegression, CSG_String::Format(SG_T("%s [%s]"), Parameters("ATTRIBUTE")->asString(), _TL("Regression Model")));
 
-	Set_Residuals(pShapes, iAttribute, pRegression);
+	Set_Residuals(pPoints, iAttribute, pRegression);
 
 	//-----------------------------------------------------
 	if( Parameters("INFO_COEFF")->asTable() )
@@ -341,7 +349,7 @@ bool CPoint_Multi_Grid_Regression::On_Execute(void)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CPoint_Multi_Grid_Regression::Get_Samples(CSG_Parameter_Grid_List *pGrids, CSG_Shapes *pShapes, int iAttribute, CSG_Matrix &Samples, CSG_Strings &Names)
+bool CPoint_Multi_Grid_Regression::Get_Samples(CSG_Parameter_Grid_List *pGrids, CSG_Shapes *pPoints, int iAttribute, CSG_Matrix &Samples, CSG_Strings &Names)
 {
 	int			iGrid;
 	double		zGrid;
@@ -352,7 +360,7 @@ bool CPoint_Multi_Grid_Regression::Get_Samples(CSG_Parameter_Grid_List *pGrids,
 	bool	bCoord_X		= Parameters("COORD_X")		->asBool();
 	bool	bCoord_Y		= Parameters("COORD_Y")		->asBool();
 
-	Names	+= pShapes->Get_Field_Name(iAttribute);		// Dependent Variable
+	Names	+= pPoints->Get_Field_Name(iAttribute);		// Dependent Variable
 
 	for(iGrid=0; iGrid<pGrids->Get_Count(); iGrid++)	// Independent Variables
 	{
@@ -365,9 +373,9 @@ bool CPoint_Multi_Grid_Regression::Get_Samples(CSG_Parameter_Grid_List *pGrids,
 	Sample.Create(1 + pGrids->Get_Count() + (bCoord_X ? 1 : 0) + (bCoord_Y ? 1 : 0));
 
 	//-----------------------------------------------------
-	for(int iShape=0; iShape<pShapes->Get_Count() && Set_Progress(iShape, pShapes->Get_Count()); iShape++)
+	for(int iShape=0; iShape<pPoints->Get_Count() && Set_Progress(iShape, pPoints->Get_Count()); iShape++)
 	{
-		CSG_Shape	*pShape	= pShapes->Get_Shape(iShape);
+		CSG_Shape	*pShape	= pPoints->Get_Shape(iShape);
 
 		if( !pShape->is_NoData(iAttribute) )
 		{
@@ -510,7 +518,7 @@ bool CPoint_Multi_Grid_Regression::Set_Regression(CSG_Parameter_Grid_List *pGrid
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CPoint_Multi_Grid_Regression::Set_Residuals(CSG_Shapes *pShapes, int iAttribute, CSG_Grid *pRegression)
+bool CPoint_Multi_Grid_Regression::Set_Residuals(CSG_Shapes *pPoints, int iAttribute, CSG_Grid *pRegression)
 {
 	CSG_Shapes	*pResiduals		= Parameters("RESIDUALS")->asShapes();
 
@@ -521,16 +529,16 @@ bool CPoint_Multi_Grid_Regression::Set_Residuals(CSG_Shapes *pShapes, int iAttri
 
 	//-----------------------------------------------------
 	pResiduals->Create(SHAPE_TYPE_Point, CSG_String::Format(SG_T("%s [%s]"), Parameters("ATTRIBUTE")->asString(), _TL("Residuals")));
-	pResiduals->Add_Field(pShapes->Get_Field_Name(iAttribute), SG_DATATYPE_Double);
+	pResiduals->Add_Field(pPoints->Get_Field_Name(iAttribute), SG_DATATYPE_Double);
 	pResiduals->Add_Field("TREND"	, SG_DATATYPE_Double);
 	pResiduals->Add_Field("RESIDUAL", SG_DATATYPE_Double);
 
 	int	Interpolation	= Parameters("INTERPOL")->asInt();
 
 	//-------------------------------------------------
-	for(int iShape=0; iShape<pShapes->Get_Count() && Set_Progress(iShape, pShapes->Get_Count()); iShape++)
+	for(int iShape=0; iShape<pPoints->Get_Count() && Set_Progress(iShape, pPoints->Get_Count()); iShape++)
 	{
-		CSG_Shape	*pShape	= pShapes->Get_Shape(iShape);
+		CSG_Shape	*pShape	= pPoints->Get_Shape(iShape);
 
 		if( !pShape->is_NoData(iAttribute) )
 		{
