@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: api_core.h 2112 2014-05-07 09:59:40Z oconrad $
+ * Version $Id: api_core.h 2252 2014-09-25 15:59:01Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -313,8 +313,10 @@ public:
 
 	void							Clear				(void);
 
-	static CSG_String				Format				(const SG_Char *Format, ...);
-	int								Printf				(const SG_Char *Format, ...);
+	static CSG_String				Format				(const char    *Format, ...);
+	static CSG_String				Format				(const wchar_t *Format, ...);
+	int								Printf				(const char    *Format, ...);
+	int								Printf				(const wchar_t *Format, ...);
 
 	size_t							Replace				(const CSG_String &sOld, const CSG_String &sNew, bool bReplaceAll = true);
 
@@ -491,7 +493,11 @@ public:
 	size_t				Get_Value_Size	(void)	const			{	return( m_Value_Size );	}
 	size_t				Get_Size		(void)	const			{	return( m_nValues );	}
 
-	void *				Get_Entry		(size_t Index)	const	{	return( Index < m_nValues ? (char *)m_Values + Index * m_Value_Size : NULL );		}
+	/// Returns a pointer to the memory address of the requested variable. You have to type cast and dereference the pointer to get access to the variable itself.
+	void *				Get_Entry		(size_t Index)	const	{	return( Index < m_nValues ? (char *)m_Values + Index * m_Value_Size : NULL );	}
+
+	/// Returns a pointer to the memory address of the requested variable. You have to type cast and dereference the pointer to get access to the variable itself.
+	void *				Get_Entry		(int    Index)	const	{	return( Index >= 0 ? Get_Entry((size_t)Index) : NULL );	}
 
 	void *				Get_Array		(void)	const			{	return( m_Values );		}
 	void *				Get_Array		(size_t nValues)		{	Set_Array(nValues);	return( m_Values );	}
@@ -920,7 +926,8 @@ public:
 
 	bool							Flush				(void)	const;
 
-	int								Printf				(const SG_Char *Format, ...);
+	int								Printf				(const char    *Format, ...);
+	int								Printf				(const wchar_t *Format, ...);
 
 	size_t							Read				(void             *Buffer, size_t Size, size_t Count = 1)	const;
 	size_t							Write				(void             *Buffer, size_t Size, size_t Count = 1)	const;
@@ -956,10 +963,11 @@ private:
 SAGA_API_DLL_EXPORT bool			SG_Dir_Exists				(const SG_Char *Directory);
 SAGA_API_DLL_EXPORT bool			SG_Dir_Create				(const SG_Char *Directory);
 SAGA_API_DLL_EXPORT CSG_String		SG_Dir_Get_Current			(void);
+SAGA_API_DLL_EXPORT CSG_String		SG_Dir_Get_Temp				(void);
 
 SAGA_API_DLL_EXPORT bool			SG_File_Exists				(const SG_Char *FileName);
 SAGA_API_DLL_EXPORT bool			SG_File_Delete				(const SG_Char *FileName);
-SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_TmpName			(const SG_Char *Prefix, const SG_Char *Directory);
+SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Name_Temp		(const SG_Char *Prefix, const SG_Char *Directory = NULL);
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Name			(const SG_Char *full_Path, bool bExtension);
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Path			(const SG_Char *full_Path);
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Path_Absolute	(const SG_Char *full_Path);
