@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: dataobject.cpp 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id: dataobject.cpp 2214 2014-09-01 15:47:38Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -357,6 +357,22 @@ bool CSG_Data_Object::Assign(CSG_Data_Object *pObject)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+#include "module_chain.h"
+
+//---------------------------------------------------------
+bool CSG_Data_Object::Save_History_to_Model(const CSG_String &File)	const
+{
+	return( CSG_Module_Chain::Save_History_to_Model(Get_History(), File) );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
