@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: grid_memory.cpp 2064 2014-03-21 13:20:57Z oconrad $
+ * Version $Id: grid_memory.cpp 2242 2014-09-22 13:27:38Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -226,7 +226,8 @@ bool CSG_Grid::_Memory_Create(TSG_Grid_Memory_Type Memory_Type)
 //---------------------------------------------------------
 void CSG_Grid::_Memory_Destroy(void)
 {
-	Set_Index(false);
+	m_bIndex	= false;
+	SG_FREE_SAFE(m_Index);
 
 	switch( m_Memory_Type )
 	{
@@ -616,7 +617,7 @@ bool CSG_Grid::_Cache_Create(void)
 
 	if( m_System.is_Valid() && m_Type != SG_DATATYPE_Undefined && m_Memory_Type == GRID_MEMORY_Normal )
 	{
-		m_Cache_Path	= SG_File_Get_TmpName(SG_T("sg_grd"), SG_Grid_Cache_Get_Directory());
+		m_Cache_Path	= SG_File_Get_Name_Temp(SG_T("sg_grd"), SG_Grid_Cache_Get_Directory());
 
 		if( m_Cache_Stream.Open(m_Cache_Path, SG_FILE_RW, true) )
 		{
