@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: module.cpp 2064 2014-03-21 13:20:57Z oconrad $
+ * Version $Id: module.cpp 2292 2014-10-17 15:00:41Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -77,7 +77,7 @@
 //---------------------------------------------------------
 CSG_Module::CSG_Module(void)
 {
-	m_ID			= -1;
+	m_ID			= "-1";
 
 	m_bError_Ignore	= false;
 	m_bExecutes		= false;
@@ -94,6 +94,14 @@ CSG_Module::CSG_Module(void)
 //---------------------------------------------------------
 CSG_Module::~CSG_Module(void)
 {
+	if( m_Settings_Stack.Get_Size() > 0 )
+	{
+		for(size_t i=0; i<m_Settings_Stack.Get_Size(); i++)
+		{
+			delete(((CSG_Parameters **)m_Settings_Stack.Get_Array())[i]);
+		}
+	}
+
 	if( m_pParameters )
 	{
 		for(int i=0; i<m_npParameters; i++)
@@ -129,13 +137,25 @@ void CSG_Module::Destroy(void)
 //														 //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+const CSG_String & CSG_Module::Get_Library(void) const
+{
+	return( m_Library );
+}
+
+//---------------------------------------------------------
+const CSG_String & CSG_Module::Get_File_Name(void) const
+{
+	return( m_File_Name );
+}
+
 //---------------------------------------------------------
 void CSG_Module::Set_Name(const CSG_String &String)
 {
 	Parameters.Set_Name(String);
 }
 
-const CSG_String & CSG_Module::Get_Name(void)
+const CSG_String & CSG_Module::Get_Name(void) const
 {
 	return( Parameters.Get_Name() );
 }
@@ -146,7 +166,7 @@ void CSG_Module::Set_Description(const CSG_String &String)
 	Parameters.Set_Description(String);
 }
 
-const CSG_String & CSG_Module::Get_Description(void)
+const CSG_String & CSG_Module::Get_Description(void) const
 {
 	return( Parameters.Get_Description() );
 }
@@ -157,7 +177,7 @@ void CSG_Module::Set_Author(const CSG_String &String)
 	m_Author	= String;
 }
 
-const CSG_String & CSG_Module::Get_Author(void)
+const CSG_String & CSG_Module::Get_Author(void) const
 {
 	return( m_Author );
 }
@@ -317,30 +337,6 @@ bool CSG_Module::Get_Projection(CSG_Projection &Projection)	const
 }
 
 
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-void CSG_Module::Set_Manager(class CSG_Data_Manager *pManager)
-{
-	Parameters.Set_Manager(pManager);
-
-	for(int i=0; i<m_npParameters; i++)
-	{
-		m_pParameters[i]->Set_Manager(pManager);
-	}
-}
-
-//---------------------------------------------------------
-void CSG_Module::Set_Show_Progress(bool bOn)
-{
-	m_bShow_Progress	= bOn;
-}
-
-
 ///////////////////////////////////////////////////////////
 //														 //
 //						Parameters						 //
@@ -441,12 +437,98 @@ bool CSG_Module::Dlg_Parameters(CSG_Parameters *pParameters, const CSG_String &C
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+void CSG_Module::Set_Manager(class CSG_Data_Manager *pManager)
+{
+	Parameters.Set_Manager(pManager);
+
+	for(int i=0; i<m_npParameters; i++)
+	{
+		m_pParameters[i]->Set_Manager(pManager);
+	}
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Module::Settings_Push(CSG_Data_Manager *pManager)
+{
+	if( m_Settings_Stack.Get_Value_Size() != sizeof(CSG_Parameters *) )
+	{
+		m_Settings_Stack.Create(sizeof(CSG_Parameters *));
+	}
+
+	int	n	= m_Settings_Stack.Get_Size();
+
+	CSG_Parameters	**pP	= (CSG_Parameters **)m_Settings_Stack.Get_Array(n + 1 + m_npParameters);
+
+	if( pP )
+	{
+		pP[n++]	= new CSG_Parameters(Parameters);	Parameters.Restore_Defaults();
+
+		for(int i=0; i<m_npParameters; i++)
+		{
+			pP[n++]	= new CSG_Parameters(*m_pParameters[i]);	m_pParameters[i]->Restore_Defaults();
+		}
+
+		Set_Manager(pManager);
+
+		return( true );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_Module::Settings_Pop(void)
+{
+	CSG_Parameters	**pP	= (CSG_Parameters **)m_Settings_Stack.Get_Array();
+
+	if( pP && (int)m_Settings_Stack.Get_Size() >= 1 + m_npParameters )
+	{
+		int	n	= m_Settings_Stack.Get_Size() - 1;
+
+		for(int i=m_npParameters-1; i>=0; i--, n--)
+		{
+			m_pParameters[i]->Assign_Values(pP[n]); delete(pP[n]);
+		}
+
+		Set_Manager(pP[n]->Get_Manager());
+
+		Parameters.Assign_Values(pP[n]); delete(pP[n]);
+
+		m_Settings_Stack.Set_Array(n);
+
+		return( true );
+	}
+
+	return( false );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //						Progress						 //
 //														 //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+void CSG_Module::Set_Show_Progress(bool bOn)
+{
+	m_bShow_Progress	= bOn;
+}
+
 //---------------------------------------------------------
 bool CSG_Module::Process_Get_Okay(bool bBlink)
 {
@@ -509,7 +591,7 @@ bool CSG_Module::Error_Set(TSG_Module_Error Error_ID)
 	{
 	default:
 		return( Error_Set(_TL("Unknown Error")) );
-	    
+
 	case MODULE_ERROR_Calculation:
 		return( Error_Set(_TL("Calculation Error")) );
 	}
@@ -537,6 +619,58 @@ bool CSG_Module::Error_Set(const CSG_String &Error_Text)
 	return( SG_UI_Process_Get_Okay(false) );
 }
 
+//---------------------------------------------------------
+#include <wx/string.h>
+
+bool CSG_Module::Error_Fmt(const char *Format, ...)
+{
+	wxString	Error;
+
+	va_list	argptr;
+	
+#ifdef _SAGA_LINUX
+	// workaround as we only use wide characters
+	// since wx 2.9.4 so interpret strings as multibyte
+	wxString	_Format(Format);	_Format.Replace("%s", "%ls");
+	va_start(argptr, _Format);
+	Error.PrintfV(_Format, argptr);
+#else
+	va_start(argptr, Format);
+	Error.PrintfV(Format, argptr);
+#endif
+
+	va_end(argptr);
+
+	CSG_String	s(&Error);
+
+	return( Error_Set(s) );
+}
+
+//---------------------------------------------------------
+bool CSG_Module::Error_Fmt(const wchar_t *Format, ...)
+{
+	wxString	Error;
+
+	va_list	argptr;
+	
+#ifdef _SAGA_LINUX
+	// workaround as we only use wide characters
+	// since wx 2.9.4 so interpret strings as multibyte
+	wxString	_Format(Format);	_Format.Replace("%s", "%ls");
+	va_start(argptr, _Format);
+	Error.PrintfV(_Format, argptr);
+#else
+	va_start(argptr, Format);
+	Error.PrintfV(Format, argptr);
+#endif
+
+	va_end(argptr);
+
+	CSG_String	s(&Error);
+
+	return( Error_Set(s) );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -552,7 +686,12 @@ bool CSG_Module::DataObject_Add(CSG_Data_Object *pDataObject, bool bUpdate)
 		Parameters.Get_Manager()->Add(pDataObject);
 	}
 
-	return( SG_UI_DataObject_Add(pDataObject, bUpdate) );
+	if( Parameters.Get_Manager() == &SG_Get_Data_Manager() )	// prevent that local data manager send their data objects to gui
+	{
+		return( SG_UI_DataObject_Add(pDataObject, bUpdate) );
+	}
+
+	return( true );
 }
 
 //---------------------------------------------------------
@@ -563,27 +702,16 @@ bool CSG_Module::DataObject_Update(CSG_Data_Object *pDataObject, int Show)
 
 bool CSG_Module::DataObject_Update(CSG_Data_Object *pDataObject, double Parm_1, double Parm_2, int Show)
 {
-	CSG_Parameters	Parameters;
-
-	if( pDataObject )
+	if( !pDataObject )
 	{
-		switch( pDataObject->Get_ObjectType() )
-		{
-		default:
-			break;
-
-		case DATAOBJECT_TYPE_Grid:
-			Parameters.Add_Range(NULL, SG_T("METRIC_ZRANGE"), SG_T(""), SG_T(""),
-				Parm_1 * ((CSG_Grid *)pDataObject)->Get_ZFactor(),
-				Parm_2 * ((CSG_Grid *)pDataObject)->Get_ZFactor()
-			);
-			break;
-		}
-
-		return( SG_UI_DataObject_Update(pDataObject, Show, &Parameters) );
+		return( false );
 	}
 
-	return( false );
+	CSG_Parameters	Parameters;
+
+	Parameters.Add_Range(NULL, SG_T("METRIC_ZRANGE"), SG_T(""), SG_T(""), Parm_1, Parm_2);
+
+	return( SG_UI_DataObject_Update(pDataObject, Show, &Parameters) );
 }
 
 //---------------------------------------------------------
@@ -765,21 +893,43 @@ void CSG_Module::_Update_Parameter_States(CSG_Parameters *pParameters)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-void CSG_Module::_Set_Output_History(void)
+#include "saga_api.h"
+
+//---------------------------------------------------------
+CSG_MetaData CSG_Module::_Get_Output_History(void)
 {
 	CSG_MetaData	History;
 
-	//-----------------------------------------------------
 	History.Set_Name(SG_META_HST);
+	History.Add_Property("saga-version", SAGA_VERSION);
 
-	History.Add_Child(SG_T("MODULE")	, Get_Name());
-//	History.Add_Child(SG_T("LIBRARY")	, Get_Library());
+	if( SG_Get_History_Depth() )
+	{
+		CSG_MetaData	*pModule	= History.Add_Child("MODULE");
 
-	Parameters.Set_History(History);
+		pModule->Add_Property("library", Get_Library());
+		pModule->Add_Property("id"     , Get_ID     ());
+		pModule->Add_Property("name"   , Get_Name   ());
 
-	History.Assign(History_Supplement, true);
+		Parameters.Set_History(*pModule);
 
-	History.Del_Children(SG_Get_History_Depth());
+		pModule->Add_Children(History_Supplement);
+
+		CSG_MetaData	*pOutput	= pModule->Add_Child("OUTPUT");
+		pOutput->Add_Property("type", "");
+		pOutput->Add_Property("id"  , "");
+		pOutput->Add_Property("name", "");
+
+		pModule->Del_Children(SG_Get_History_Depth(), SG_T("MODULE"));
+	}
+
+	return( History );
+}
+
+//---------------------------------------------------------
+void CSG_Module::_Set_Output_History(void)
+{
+	CSG_MetaData	History(_Get_Output_History());
 
 	//-----------------------------------------------------
 	for(int j=-1; j<Get_Parameters_Count(); j++)
@@ -788,27 +938,80 @@ void CSG_Module::_Set_Output_History(void)
 
 		for(int i=0; i<pParameters->Get_Count(); i++)
 		{
-			CSG_Parameter	*p	= pParameters->Get_Parameter(i);
+			CSG_Parameter	*pParameter	= pParameters->Get_Parameter(i);
 
-			if( p->is_Output() && p->is_Enabled() )
+			if( pParameter->is_Output() )//&& (pParameter->is_Enabled() || !SG_UI_Get_Window_Main()) )
 			{
-				if( p->is_DataObject() && p->asDataObject() )
-				{
-					p->asDataObject()->Get_History().Assign(History);
-				}
-
-				if( p->is_DataObject_List() )
-				{
-					for(int j=0; j<p->asList()->Get_Count(); j++)
-					{
-						p->asList()->asDataObject(j)->Get_History().Assign(History);
-					}
-				}
+				DataObject_Set_History(pParameter, &History);
 			}
 		}
 	}
 }
 
+//---------------------------------------------------------
+bool CSG_Module::DataObject_Set_History(CSG_Parameter *pParameter, CSG_MetaData *pHistory)
+{
+	if( !pParameter )
+	{
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	CSG_MetaData	History;
+
+	if( !pHistory )
+	{
+		History		= _Get_Output_History();
+
+		pHistory	= &History;
+	}
+
+	//-----------------------------------------------------
+	CSG_MetaData	*pOutput	= pHistory->Get_Child("MODULE") ? pHistory->Get_Child("MODULE")->Get_Child("OUTPUT") : NULL;
+
+	if( pOutput )
+	{
+		pOutput->Set_Property("type", pParameter->Get_Type_Identifier());
+		pOutput->Set_Property("id"  , pParameter->Get_Identifier     ());
+		pOutput->Set_Property("name", pParameter->Get_Name           ());
+	}
+
+	//-----------------------------------------------------
+	if( pParameter->is_DataObject() )
+	{
+		if( pParameter->asDataObject() )
+		{
+			if( pOutput )
+			{
+				pOutput->Set_Content(pParameter->asDataObject()->Get_Name());
+			}
+
+			pParameter->asDataObject()->Get_History().Assign(*pHistory);
+
+			return( true );
+		}
+	}
+
+	//-----------------------------------------------------
+	else if( pParameter->is_DataObject_List() )
+	{
+		for(int j=0; j<pParameter->asList()->Get_Count(); j++)
+		{
+			if( pOutput )
+			{
+				pOutput->Set_Content(pParameter->asList()->asDataObject(j)->Get_Name());
+			}
+
+			pParameter->asList()->asDataObject(j)->Get_History().Assign(*pHistory);
+		}
+
+		return( true );
+	}
+
+	//-----------------------------------------------------
+	return( false );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -947,7 +1150,7 @@ CSG_String CSG_Module::Get_Summary(bool bParameters, const CSG_String &Menu, con
 		s	+= CSG_String::Format(SG_T("<b>%s</b><table border=\"0\">"), _TL("Tool"));
 
 		SUMMARY_ADD_STR(_TL("Name"  ), Get_Name  ().c_str());
-		SUMMARY_ADD_INT(_TL("ID"    ), Get_ID    ());
+		SUMMARY_ADD_STR(_TL("ID"    ), Get_ID    ().c_str());
 		SUMMARY_ADD_STR(_TL("Author"), Get_Author().c_str());
 
 		if( is_Interactive() && is_Grid() )
@@ -963,6 +1166,11 @@ CSG_String CSG_Module::Get_Summary(bool bParameters, const CSG_String &Menu, con
 			SUMMARY_ADD_STR(_TL("Specification"), _TL("grid"));
 		}
 
+		if( Get_Type() == MODULE_TYPE_Chain )
+		{
+			SUMMARY_ADD_STR(_TL("File"), Get_File_Name().c_str() );
+		}
+
 		if( Menu.Length() > 0 )
 		{
 			CSG_String	sMenu(Menu);
