@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: module.h 2111 2014-05-07 09:58:48Z oconrad $
+ * Version $Id: module.h 2284 2014-10-10 10:01:30Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -143,7 +143,8 @@ typedef enum ESG_Module_Type
 	MODULE_TYPE_Base			= 0,
 	MODULE_TYPE_Interactive,
 	MODULE_TYPE_Grid,
-	MODULE_TYPE_Grid_Interactive
+	MODULE_TYPE_Grid_Interactive,
+	MODULE_TYPE_Chain
 }
 TSG_Module_Type;
 
@@ -182,6 +183,7 @@ class SAGA_API_DLL_EXPORT CSG_Module
 {
 	friend class CSG_Module_Interactive_Base;
 	friend class CSG_Module_Library_Interface;
+	friend class CSG_Module_Chain;
 
 public:
 
@@ -192,11 +194,13 @@ public:
 
 	virtual TSG_Module_Type		Get_Type					(void)	{	return( MODULE_TYPE_Base );	}
 
-	int							Get_ID						(void)	{	return( m_ID );	}
+	const CSG_String &			Get_ID						(void)	const	{	return( m_ID );	}
 
-	const CSG_String &			Get_Name					(void);
-	const CSG_String &			Get_Description				(void);
-	const CSG_String &			Get_Author					(void);
+	const CSG_String &			Get_Library					(void)	const;
+	const CSG_String &			Get_File_Name				(void)	const;	// Returns the file name of the module's library or, if this is a module chain, the associated XML file.
+	const CSG_String &			Get_Name					(void)	const;
+	const CSG_String &			Get_Description				(void)	const;
+	const CSG_String &			Get_Author					(void)	const;
 	const SG_Char *				Get_Icon					(void)	{	return( NULL );	}
 	CSG_String					Get_Summary					(bool bParameters = true, const CSG_String &Menu = "", const CSG_String &Description = "", bool bXML = false);
 
@@ -209,6 +213,11 @@ public:
 
 	bool						Update_Parameter_States		(void);
 
+	void						Set_Manager					(class CSG_Data_Manager *pManager);
+
+	bool						Settings_Push				(class CSG_Data_Manager *pManager = NULL);
+	bool						Settings_Pop				(void);
+
 	virtual bool				do_Sync_Projections			(void)	{	return( true  );	}
 
 	virtual bool				needs_GUI					(void)	{	return( false );	}
@@ -218,8 +227,6 @@ public:
 	bool						is_Progress					(void)	{	return( SG_UI_Process_Get_Okay(false) );	}
 	bool						is_Executing				(void)	{	return( m_bExecutes );	}
 
-	void						Set_Manager					(class CSG_Data_Manager *pManager);
-
 	void						Set_Show_Progress			(bool bOn = true);
 
 	virtual bool				On_Before_Execution			(void)	{	return( true );	}
@@ -269,6 +276,8 @@ protected:
 
 	bool						Error_Set					(TSG_Module_Error Error_ID = MODULE_ERROR_Unknown);
 	bool						Error_Set					(const CSG_String &Error_Text);
+	bool						Error_Fmt					(const char    *Format, ...);
+	bool						Error_Fmt					(const wchar_t *Format, ...);
 
 
 	//-----------------------------------------------------
@@ -293,6 +302,8 @@ protected:
 	bool						DataObject_Set_Parameter	(CSG_Data_Object *pDataObject, const CSG_String &ID, const SG_Char *Value);
 	bool						DataObject_Set_Parameter	(CSG_Data_Object *pDataObject, const CSG_String &ID, double loVal, double hiVal);	// Range Parameter
 
+	bool						DataObject_Set_History		(CSG_Parameter *pParameter, CSG_MetaData *pHistory = NULL);
+
 	bool						Get_Projection				(CSG_Projection &Projection)	const;
 
 
@@ -300,15 +311,18 @@ private:
 
 	bool						m_bExecutes, m_bError_Ignore, m_bShow_Progress;
 
-	int							m_ID, m_npParameters;
+	int							m_npParameters;
+
+	CSG_Array					m_Settings_Stack;
 
 	CSG_Parameters				**m_pParameters;
 
-	CSG_String					m_Author;
+	CSG_String					m_ID, m_Library, m_File_Name, m_Author;
 
 
 	bool						_Synchronize_DataObjects	(void);
 
+	CSG_MetaData				_Get_Output_History			(void);
 	void						_Set_Output_History			(void);
 
 	void						_Update_Parameter_States	(CSG_Parameters *pParameters);
@@ -561,7 +575,10 @@ typedef enum ESG_MLB_Info
 	MLB_INFO_Author,
 	MLB_INFO_Version,
 	MLB_INFO_Menu_Path,
+	MLB_INFO_Category,
 	MLB_INFO_User,
+	MLB_INFO_File,
+	MLB_INFO_Library,
 	MLB_INFO_Count
 }
 TSG_MLB_Info;
@@ -581,12 +598,11 @@ public:
 	CSG_Module *				Get_Module				(int iModule);
 
 	void						Set_File_Name			(const CSG_String &File_Name);
-	const CSG_String &			Get_File_Name			(void)	{	return( m_File_Name );	}
 
 
 private:
 
-	CSG_String					m_File_Name, m_Info[MLB_INFO_Count];
+	CSG_String					m_Info[MLB_INFO_Count];
 
 	int							m_nModules;
 
@@ -629,7 +645,7 @@ extern "C" _SAGA_DLL_EXPORT const SG_Char *					Get_Version			(void)\
 \
 	while( MLB_Interface.Add_Module(Create_Module(i), i) ) i++;\
 \
-	for(i=0; i<MLB_INFO_Count; i++)\
+	for(i=0; i<MLB_INFO_User; i++)\
 	{\
 		MLB_Interface.Set_Info(i, Get_Info(i));\
 	}\
