@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: saga_cmd.cpp 2111 2014-05-07 09:58:48Z oconrad $
+ * Version $Id: saga_cmd.cpp 2281 2014-10-09 15:49:41Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -180,6 +180,8 @@ bool		Run(int argc, char *argv[])
 		argc--;	argv++;
 	}
 
+	Print_Logo();
+
 	//-----------------------------------------------------
 	if( !Load_Libraries() )
 	{
@@ -199,8 +201,6 @@ bool		Run(int argc, char *argv[])
 	}
 
 	//-----------------------------------------------------
-	Print_Logo();
-
 	if( argc == 2 && SG_File_Exists(CSG_String(argv[1])) )
 	{
 		return( Execute_Script(argv[1]) );
@@ -257,9 +257,9 @@ bool		Execute(int argc, char *argv[])
 	//-----------------------------------------------------
 	Print_Execution(pLibrary, pModule);
 
-	CCMD_Module	CMD_Module(pModule);
+	CCMD_Module	CMD_Module(pLibrary, pModule);
 
-	return( CMD_Module.Execute(pLibrary->Get_Library_Name(), argc - 2, argv + 2) );
+	return( CMD_Module.Execute(argc - 2, argv + 2) );
 }
 
 
@@ -445,28 +445,28 @@ bool		Load_Libraries(void)
 //---------------------------------------------------------
 bool		Check_First		(const CSG_String &Argument)
 {
-	if( !Argument.CmpNoCase(SG_T("-h")) || !Argument.CmpNoCase(SG_T("--help")) )
+	if( !Argument.CmpNoCase("-h") || !Argument.CmpNoCase("--help") )
 	{
 		Print_Help();
 
 		return( true );
 	}
 
-	if( !Argument.CmpNoCase(SG_T("-v")) || !Argument.CmpNoCase(SG_T("--version")) )
+	if( !Argument.CmpNoCase("-v") || !Argument.CmpNoCase("--version") )
 	{
 		Print_Version();
 
 		return( true );
 	}
 
-	if( !Argument.CmpNoCase(SG_T("-b")) || !Argument.CmpNoCase(SG_T("--batch")) )
+	if( !Argument.CmpNoCase("-b") || !Argument.CmpNoCase("--batch") )
 	{
 		Create_Example();
 
 		return( true );
 	}
 
-	if( !Argument.CmpNoCase(SG_T("-d")) || !Argument.CmpNoCase(SG_T("--docs")) )
+	if( !Argument.CmpNoCase("-d") || !Argument.CmpNoCase("--docs") )
 	{
 		Create_Docs();
 
@@ -481,7 +481,7 @@ bool		Check_Flags		(const CSG_String &Argument)
 {
 	CSG_String	s(Argument.BeforeFirst(SG_T('=')));
 
-	if( !s.CmpNoCase(SG_T("-f")) || !s.CmpNoCase(SG_T("--flags")) )
+	if( !s.CmpNoCase("-f") || !s.CmpNoCase("--flags") )
 	{
 		s	= CSG_String(Argument).AfterFirst(SG_T('='));
 
@@ -516,12 +516,12 @@ bool		Check_Flags		(const CSG_String &Argument)
 		return( true );
 	}
 
-	else if( !s.CmpNoCase(SG_T("-c")) || !s.CmpNoCase(SG_T("--cores")) )
+	else if( !s.CmpNoCase("-c") || !s.CmpNoCase("--cores") )
 	{
 		#ifdef _OPENMP
 		int	nCores	= 1;
 
-		if( !CSG_String(Argument).AfterFirst(SG_T('=')).asInt(nCores) || nCores > SG_Get_Max_Num_Procs_Omp() )
+		if( !CSG_String(Argument).AfterFirst('=').asInt(nCores) || nCores > SG_Get_Max_Num_Procs_Omp() )
 		{
 			nCores	= SG_Get_Max_Num_Procs_Omp();
 		}
@@ -532,6 +532,18 @@ bool		Check_Flags		(const CSG_String &Argument)
 		return( true );
 	}
 
+	else if( !s.CmpNoCase("-s") || !s.CmpNoCase("--story") )
+	{
+		int	Depth;
+
+		if( CSG_String(Argument).AfterFirst('=').asInt(Depth) )
+		{
+			SG_Set_History_Depth(Depth);
+		}
+
+		return( true );
+	}
+
 	return( false );
 }
 
@@ -545,7 +557,7 @@ bool		Check_Flags		(const CSG_String &Argument)
 //---------------------------------------------------------
 void		Print_Libraries	(void)
 {
-	CMD_Print_Error(_TL("library"));
+	CMD_Print_Error(_TL("select a library"));
 
 	if( CMD_Get_Show_Messages() )
 	{
@@ -565,7 +577,7 @@ void		Print_Libraries	(void)
 //---------------------------------------------------------
 void		Print_Modules	(CSG_Module_Library *pLibrary)
 {
-	CMD_Print_Error(_TL("tool"));
+	CMD_Print_Error(_TL("select a tool"));
 
 	if( CMD_Get_Show_Messages() )
 	{
@@ -597,12 +609,16 @@ void		Print_Execution	(CSG_Module_Library *pLibrary, CSG_Module *pModule)
 		}
 		else
 		{
-			SG_PRINTF(SG_T("_____________________________________________\n"));
-			SG_PRINTF(SG_T("%s:\t%s\n"), _TL("library path"), pLibrary->Get_File_Name().c_str());
-			SG_PRINTF(SG_T("%s:\t%s\n"), _TL("library name"), pLibrary->Get_Name     ().c_str());
-			SG_PRINTF(SG_T("%s:\t%s\n"), _TL("tool name   "), pModule ->Get_Name     ().c_str());
-			SG_PRINTF(SG_T("%s:\t%s\n"), _TL("author      "), pModule ->Get_Author   ().c_str());
-			SG_PRINTF(SG_T("_____________________________________________\n\n"));
+			SG_PRINTF(SG_T("____________________________\n"));
+			SG_PRINTF(SG_T("%s:\t%s\n"     ), _TL("library path"), SG_File_Get_Path(pLibrary->Get_File_Name()       ).c_str());
+			SG_PRINTF(SG_T("%s:\t%s\n"     ), _TL("library name"), SG_File_Get_Name(pLibrary->Get_File_Name(), false).c_str());
+			SG_PRINTF(SG_T("%s:\t%s\n"     ), _TL("library     "), pLibrary->Get_Name     ().c_str());
+			SG_PRINTF(SG_T("%s:\t%s\n"     ), _TL("tool        "), pModule ->Get_Name     ().c_str());
+			SG_PRINTF(SG_T("%s:\t%s\n"     ), _TL("author      "), pModule ->Get_Author   ().c_str());
+		#ifdef _OPENMP
+			SG_PRINTF(SG_T("%s:\t%d [%d]\n"), _TL("processors  "), SG_Get_Max_Num_Threads_Omp(), SG_Get_Max_Num_Procs_Omp());
+		#endif // _OPENMP
+			SG_PRINTF(SG_T("____________________________\n\n"));
 		}
 	}
 }
@@ -620,15 +636,17 @@ void		Print_Logo		(void)
 	if( CMD_Get_Show_Messages() )
 	{
 		CMD_Print(
-			"_____________________________________________\n"
+			"____________________________\n"
 			"\n"
 			"   #####   ##   #####    ##\n"
 			"  ###     ###  ##       ###\n"
 			"   ###   # ## ##  #### # ##\n"
 			"    ### ##### ##    # #####\n"
 			" ##### #   ##  ##### #   ##\n"
-			"_____________________________________________\n"
+			"____________________________\n"
 		);
+
+		Print_Version();
 	}
 }
 
@@ -659,12 +677,10 @@ void		Print_Help		(void)
 {
 	Print_Logo();
 
-	Print_Version();
-
 	CMD_Print(
 		"under GNU General Public License (GPL)\n"
 		"\n"
-		"_____________________________________________\n"
+		"____________________________\n"
 		"Usage:\n"
 		"\n"
 		"saga_cmd [-h, --help]\n"
@@ -672,17 +688,18 @@ void		Print_Help		(void)
 		"saga_cmd [-b, --batch]\n"
 		"saga_cmd [-d, --docs]\n"
 #ifdef _OPENMP
-		"saga_cmd [-f, --flags][=qrsilpxo][-c, --cores][=#] <LIBRARY> <MODULE> <OPTIONS>\n"
-		"saga_cmd [-f, --flags][=qrsilpxo][-c, --cores][=#] <SCRIPT>\n"
+		"saga_cmd [-f, --flags][=qrsilpxo][-s, --story][=#][-c, --cores][=#] <LIBRARY> <MODULE> <OPTIONS>\n"
+		"saga_cmd [-f, --flags][=qrsilpxo][-s, --story][=#][-c, --cores][=#] <SCRIPT>\n"
 #else
-		"saga_cmd [-f, --flags][=qrsilpxo] <LIBRARY> <MODULE> <module specific options...>\n"
-		"saga_cmd [-f, --flags][=qrsilpxo] <SCRIPT>\n"
+		"saga_cmd [-f, --flags][=qrsilpxo][-s, --story][=#] <LIBRARY> <MODULE> <module specific options...>\n"
+		"saga_cmd [-f, --flags][=qrsilpxo][-s, --story][=#] <SCRIPT>\n"
 #endif
 		"\n"
 		"[-h], [--help]   : help on usage\n"
 		"[-v], [--version]: print version information\n"
 		"[-b], [--batch]  : create a batch file example\n"
 		"[-d], [--docs]   : create tool documentation in current working directory\n"
+		"[-s], [--story]  : maximum data history depth (default is unlimited)\n"
 #ifdef _OPENMP
 		"[-c], [--cores]  : number of physical processors to use for computation\n"
 #endif
@@ -701,12 +718,12 @@ void		Print_Help		(void)
 		"<OPTIONS>        : tool specific options\n"
 		"<SCRIPT>         : saga cmd script file with one or more tool calls\n"
 		"\n"
-		"_____________________________________________\n"
+		"____________________________\n"
 		"Example:\n"
 		"\n"
 		"  saga_cmd -f=s ta_lighting 0 -ELEVATION=c:\\dem.sgrd -SHADE=c:\\shade.sgrd\n"
 		"\n"
-		"_____________________________________________\n"
+		"____________________________\n"
 		"Tool libraries in the \'modules\' subdirectory of the SAGA installation\n"
 		"will be loaded automatically. Additional directories can be specified\n"
 		"by adding the environment variable \'SAGA_MLB\' and let it point to one\n"
@@ -717,7 +734,7 @@ void		Print_Help		(void)
 		"script file. Calling saga_cmd with the option \'-b\' or \'--batch\' will\n"
 		"create an example of a DOS batch script file, which might be a good starting\n"
 		"point for the implementation of your own specific work flows.\n"
-		"_____________________________________________\n"
+		"____________________________\n"
 	);
 }
 
@@ -729,6 +746,8 @@ void		Print_Help		(void)
 //---------------------------------------------------------
 void		Create_Example	(void)
 {
+	Print_Logo();
+
 	CSG_File	Stream;
 
 	CMD_Print(_TL("creating batch file example"));
@@ -741,7 +760,7 @@ void		Create_Example	(void)
 		return;
 	}
 
-	Stream.Printf(CSG_String(
+	Stream.Printf(
 		"@ECHO OFF\n"
 		"\n"
 		"SET FLAGS=-f=q\n"
@@ -752,13 +771,13 @@ void		Create_Example	(void)
 		"IF EXIST dem.sgrd GOTO :GO\n"
 		"IF EXIST srtm.tif GOTO :SRTM\n"
 		"\n"
-		"ECHO _____________________________________________\n"
+		"ECHO ____________________________\n"
 		"ECHO create a Gaussian landscape\n"
 		"saga_cmd %%FLAGS%% recreations_fractals 5 -GRID=dem.sgrd -NX=400 -NY=400 -H=0.75\n"
 		"GOTO :GO\n"
 		"\n"
 		":SRTM\n"
-		"ECHO _____________________________________________\n"
+		"ECHO ____________________________\n"
 		"ECHO import and project srtm (geotiff)\n"
 		"saga_cmd %%FLAGS%% io_gdal              0 -FILES=srtm.tif -GRIDS=srtm -TRANSFORM\n"
 		"saga_cmd %%FLAGS%% pj_proj4             7 -SOURCE=srtm.sgrd -GET_USER_GRID=dem.sgrd -GET_USER_SIZE=1000.0 -SOURCE_PROJ=\"+proj=longlat +datum=WGS84\" -TARGET_PROJ=\"+proj=cea +datum=WGS84 +lat_ts=0\"\n"
@@ -766,24 +785,24 @@ void		Create_Example	(void)
 		"REM saga_cmd -f=qp pj_proj4             4 -SOURCE=srtm.sgrd -GET_USER_GRID=dem.sgrd -GET_USER_SIZE=1000.0 -CRS_PROJ4=\"+proj=cea +datum=WGS84 +lat_ts=0\"\n"
 		"\n"
 		":GO\n"
-		"ECHO _____________________________________________\n"
+		"ECHO ____________________________\n"
 		"ECHO create contour lines from DEM\n"
 		"saga_cmd %%FLAGS%% shapes_grid          5 -INPUT=dem.sgrd -CONTOUR=contour.shp -ZSTEP=100.0\n"
 		"\n"
-		"ECHO _____________________________________________\n"
+		"ECHO ____________________________\n"
 		"ECHO do some terrain analysis\n"
 		"saga_cmd %%FLAGS%% ta_preprocessor      2 -DEM=dem.sgrd -DEM_PREPROC=dem.sgrd\n"
 		"saga_cmd %%FLAGS%% ta_lighting          0 -ELEVATION=dem.sgrd -SHADE=shade.sgrd -METHOD=0 -AZIMUTH=-45 -DECLINATION=45\n"
 		"saga_cmd %%FLAGS%% ta_morphometry       0 -ELEVATION=dem.sgrd -SLOPE=slope.sgrd -ASPECT=aspect.sgrd -HCURV=hcurv.sgrd -VCURV=vcurv.sgrd\n"
 		"saga_cmd %%FLAGS%% ta_hydrology         0 -ELEVATION=dem.sgrd -CAREA=carea.sgrd\n"
 		"\n"
-		"ECHO _____________________________________________\n"
+		"ECHO ____________________________\n"
 		"ECHO run saga cmd script\n"
 		"SET INPUT=dem.sgrd;slope.sgrd;hcurv.sgrd;vcurv.sgrd\n"
 		"saga_cmd %%FLAGS%% saga_cmd_example.txt\n"
 		"\n"
 		"PAUSE\n"
-	));
+	);
 
 	//-----------------------------------------------------
 	if( !Stream.Open(SG_File_Make_Path(SG_Dir_Get_Current(), SG_T("saga_cmd_example"), SG_T("txt")), SG_FILE_W, false) )
@@ -793,11 +812,11 @@ void		Create_Example	(void)
 		return;
 	}
 
-	Stream.Printf(CSG_String(
+	Stream.Printf(
 		"REM \'REM\' or \'#\' can be used for comments, \'ECHO\' for message output.\n"
 		"REM environment variables can be accessed using the ms-dos/window style\n"
 		"\n"
-		"ECHO _____________________________________________\n"
+		"ECHO ____________________________\n"
 		"ECHO cluster analysis and vectorisation\n"
 		"\n"
 		"# cluster analysis\n"
@@ -815,9 +834,9 @@ void		Create_Example	(void)
 		"# save selectione\n"
 		"shapes_tools           6 -INPUT=cluster.shp -OUTPUT=cluster_class1.shp\n"
 		"\n"
-		"ECHO _____________________________________________\n"
+		"ECHO ____________________________\n"
 		"ECHO\n"
-	));
+	);
 
 	//-----------------------------------------------------
 	CMD_Print(_TL("okay"));
