@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: view_scatterplot.cpp 2064 2014-03-21 13:20:57Z oconrad $
+ * Version $Id: view_scatterplot.cpp 2273 2014-10-02 15:42:12Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -895,7 +895,7 @@ bool CVIEW_ScatterPlot::_Initialize_Shapes(void)
 	{
 		CSG_Shape	*pShape	= pPoints->Get_Shape((int)i);
 
-		if( !pShape->is_NoData(Field) && m_pGrid->Get_Value(pShape->Get_Point(0), z, GRID_INTERPOLATION_BSpline, true) )
+		if( !pShape->is_NoData(Field) && m_pGrid->Get_Value(pShape->Get_Point(0), z, GRID_INTERPOLATION_BSpline, false, true) )
 		{
 			m_Regression.Add_Values(z, pShape->asDouble(Field));
 		}
