@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: wksp_grid.cpp 2064 2014-03-21 13:20:57Z oconrad $
+ * Version $Id: wksp_grid.cpp 2297 2014-10-19 18:47:23Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -144,8 +144,8 @@ wxString CWKSP_Grid::Get_Description(void)
 	DESC_ADD_FLT (_TL("Value Maximum")		, Get_Grid()->Get_ZMax());
 	DESC_ADD_FLT (_TL("Value Range")		, Get_Grid()->Get_ZRange());
 	DESC_ADD_STR (_TL("No Data Value")		, Get_Grid()->Get_NoData_Value() < Get_Grid()->Get_NoData_hiValue() ? CSG_String::Format(SG_T("%f - %f"), Get_Grid()->Get_NoData_Value(), Get_Grid()->Get_NoData_hiValue()).c_str() : SG_Get_String(Get_Grid()->Get_NoData_Value(), -2).c_str());
-	DESC_ADD_FLT (_TL("Arithmetic Mean")	, Get_Grid()->Get_ArithMean(true));
-	DESC_ADD_FLT (_TL("Standard Deviation")	, Get_Grid()->Get_StdDev(true));
+	DESC_ADD_FLT (_TL("Arithmetic Mean")	, Get_Grid()->Get_Mean());
+	DESC_ADD_FLT (_TL("Standard Deviation")	, Get_Grid()->Get_StdDev());
 	DESC_ADD_STR (_TL("Memory Size")		, Get_nBytes_asString(Get_Grid()->Get_Memory_Size(), 2).c_str());
 
 	if( Get_Grid()->is_Compressed() )
@@ -184,16 +184,18 @@ wxMenu * CWKSP_Grid::Get_Menu(void)
 	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, true , ID_CMD_GRIDS_HISTOGRAM);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_GRIDS_SCATTERPLOT);
+	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_SETTINGS_COPY);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_GRIDS_SET_LUT);
 
 	//-----------------------------------------------------
-	wxMenu	*pSubMenu	= new wxMenu(_TL("Classification"));
+	wxMenu	*pSubMenu	= new wxMenu(_TL("Histogram Stretch"));
 
-	CMD_Menu_Add_Item(pSubMenu, false, ID_CMD_GRIDS_SET_LUT);
 	CMD_Menu_Add_Item(pSubMenu, false, ID_CMD_GRIDS_FIT_MINMAX);
 	CMD_Menu_Add_Item(pSubMenu, false, ID_CMD_GRIDS_FIT_STDDEV);
+	CMD_Menu_Add_Item(pSubMenu, false, ID_CMD_GRIDS_FIT_PCTL);
 
-	pMenu->Append(ID_CMD_WKSP_FIRST, _TL("Classification"), pSubMenu);
+	pMenu->Append(ID_CMD_WKSP_FIRST, _TL("Histogram Stretch"), pSubMenu);
 
 	return( pMenu );
 }
@@ -227,8 +229,8 @@ bool CWKSP_Grid::On_Command(int Cmd_ID)
 
 	case ID_CMD_GRIDS_FIT_MINMAX:
 		Set_Color_Range(
-			Get_Grid()->Get_ZMin(true),
-			Get_Grid()->Get_ZMax(true)
+			Get_Grid()->Get_ZMin(),
+			Get_Grid()->Get_ZMax()
 		);
 		break;
 
@@ -236,9 +238,23 @@ bool CWKSP_Grid::On_Command(int Cmd_ID)
 		{
 			double	d	= g_pData->Get_Parameter("GRID_COLORS_FIT_STDDEV")->asDouble();
 
+			double	min	= Get_Grid()->Get_Mean() - d * Get_Grid()->Get_StdDev();
+			double	max	= Get_Grid()->Get_Mean() + d * Get_Grid()->Get_StdDev();
+
 			Set_Color_Range(
-				Get_Grid()->Get_ArithMean(true) - d * Get_Grid()->Get_StdDev(true),
-				Get_Grid()->Get_ArithMean(true) + d * Get_Grid()->Get_StdDev(true)
+				min < Get_Grid()->Get_ZMin() ? Get_Grid()->Get_ZMin() : min,
+				max > Get_Grid()->Get_ZMax() ? Get_Grid()->Get_ZMax() : max
+			);
+		}
+		break;
+
+	case ID_CMD_GRIDS_FIT_PCTL:
+		{
+			double	d	= g_pData->Get_Parameter("GRID_COLORS_FIT_PCTL")->asDouble();
+
+			Set_Color_Range(
+				Get_Grid()->Get_Percentile(        d),
+				Get_Grid()->Get_Percentile(100.0 - d)
 			);
 		}
 		break;
@@ -308,9 +324,15 @@ void CWKSP_Grid::On_Create_Parameters(void)
 	);
 
 	m_Parameters.Add_Value(
-		m_Parameters("NODE_GENERAL")	, "GENERAL_Z_FACTOR"		, _TL("Z-Factor"),
+		m_Parameters("NODE_GENERAL")	, "GENERAL_Z_FACTOR"		, _TL("Z-Scale"),
 		_TL(""),
-		PARAMETER_TYPE_Double
+		PARAMETER_TYPE_Double, 1.0
+	);
+
+	m_Parameters.Add_Value(
+		m_Parameters("NODE_GENERAL")	, "GENERAL_Z_OFFSET"		, _TL("Z-Offset"),
+		_TL(""),
+		PARAMETER_TYPE_Double, 0.0
 	);
 
 	//-----------------------------------------------------
@@ -339,7 +361,7 @@ void CWKSP_Grid::On_Create_Parameters(void)
 			_TL("Graduated Colors"),	// CLASSIFY_GRADUATED
 			_TL("Shade"           ),	// CLASSIFY_SHADE
 			_TL("RGB Overlay"     ),	// CLASSIFY_OVERLAY
-			_TL("RGB"             )		// CLASSIFY_RGB
+			_TL("RGB Composite"   )		// CLASSIFY_RGB
 		)
 	);
 
@@ -484,7 +506,11 @@ void CWKSP_Grid::On_DataObject_Changed(void)
 	);
 
 	m_Parameters("GENERAL_Z_FACTOR"  )->Set_Value(
-		Get_Grid()->Get_ZFactor()
+		Get_Grid()->Get_Scaling()
+	);
+
+	m_Parameters("GENERAL_Z_OFFSET"  )->Set_Value(
+		Get_Grid()->Get_Offset()
 	);
 
 	//-----------------------------------------------------
@@ -504,7 +530,7 @@ void CWKSP_Grid::On_Parameters_Changed(void)
 
 	//-----------------------------------------------------
 	Get_Grid()->Set_Unit   (m_Parameters("GENERAL_Z_UNIT"  )->asString());
-	Get_Grid()->Set_ZFactor(m_Parameters("GENERAL_Z_FACTOR")->asDouble());
+	Get_Grid()->Set_Scaling(m_Parameters("GENERAL_Z_FACTOR")->asDouble(), m_Parameters("GENERAL_Z_OFFSET")->asDouble());
 
 	//-----------------------------------------------------
 	m_pOverlay[0]	= (CWKSP_Grid *)g_pData->Get(m_Parameters("OVERLAY_1")->asGrid());
@@ -606,7 +632,7 @@ void CWKSP_Grid::_LUT_Create(void)
 {
 	int				Type;
 	CSG_Colors		*pColors;
-	CSG_Table		*pLUT;
+	CSG_Table		LUT;
 
 	//-----------------------------------------------------
 	static CSG_Parameters	Parameters;
@@ -637,26 +663,27 @@ void CWKSP_Grid::_LUT_Create(void)
 	}
 
 	//-----------------------------------------------------
-	pColors	= Parameters("COLOR")	->asColors();
-	Type	= Parameters("TYPE")	->asInt();
+	pColors	= Parameters("COLOR")->asColors();
+	Type	= Parameters("TYPE" )->asInt();
 
-	pLUT	= m_Parameters("LUT")	->asTable();
-	pLUT	->Del_Records();
+	LUT.Create(*m_Parameters("LUT")->asTable());
+	LUT.Del_Records();
 
 	switch( Type )
 	{
 	//-----------------------------------------------------
 	case 0:	// unique values
+		if( Get_Grid()->Set_Index() )
 		{
 			double		Value;
 
 			for(sLong iCell=0, jCell; iCell<Get_Grid()->Get_NCells() && PROGRESSBAR_Set_Position(iCell, Get_Grid()->Get_NCells()); iCell++)
 			{
-				if( Get_Grid()->Get_Sorted(iCell, jCell, false) && (pLUT->Get_Record_Count() == 0 || Value != Get_Grid()->asDouble(jCell)) )
+				if( Get_Grid()->Get_Sorted(iCell, jCell, false) && (LUT.Get_Record_Count() == 0 || Value != Get_Grid()->asDouble(jCell)) )
 				{
 					Value	= Get_Grid()->asDouble(jCell);
 
-					CSG_Table_Record	*pClass	= pLUT->Add_Record();
+					CSG_Table_Record	*pClass	= LUT.Add_Record();
 
 					pClass->Set_Value(1, SG_Get_String(Value, -2));		// Name
 					pClass->Set_Value(2, SG_Get_String(Value, -2));		// Description
@@ -665,17 +692,18 @@ void CWKSP_Grid::_LUT_Create(void)
 				}
 			}
 
-			pColors->Set_Count(pLUT->Get_Count());
+			pColors->Set_Count(LUT.Get_Count());
 
-			for(int iClass=0; iClass<pLUT->Get_Count(); iClass++)
+			for(int iClass=0; iClass<LUT.Get_Count(); iClass++)
 			{
-				pLUT->Get_Record(iClass)->Set_Value(0, pColors->Get_Color(iClass));
+				LUT.Get_Record(iClass)->Set_Value(0, pColors->Get_Color(iClass));
 			}
 		}
 		break;
 
 	//-----------------------------------------------------
 	case 1:	// equal intervals
+		if( Get_Grid()->Get_ZRange() && pColors->Get_Count() > 0 )
 		{
 			double	Minimum, Maximum, Interval;
 
@@ -691,7 +719,7 @@ void CWKSP_Grid::_LUT_Create(void)
 					SG_Get_String(Maximum, -2).c_str()
 				);
 
-				CSG_Table_Record	*pClass	= pLUT->Add_Record();
+				CSG_Table_Record	*pClass	= LUT.Add_Record();
 
 				pClass->Set_Value(0, pColors->Get_Color(iClass));
 				pClass->Set_Value(1, sValue);	// Name
@@ -739,7 +767,7 @@ void CWKSP_Grid::_LUT_Create(void)
 					SG_Get_String(Maximum, -2).c_str()
 				);
 
-				CSG_Table_Record	*pClass	= pLUT->Add_Record();
+				CSG_Table_Record	*pClass	= LUT.Add_Record();
 
 				pClass->Set_Value(0, pColors->Get_Color(iClass));
 				pClass->Set_Value(1, sValue);	// Name
@@ -754,11 +782,16 @@ void CWKSP_Grid::_LUT_Create(void)
 	//-----------------------------------------------------
 	PROGRESSBAR_Set_Position(0);
 
-	DataObject_Changed();
+	if( LUT.Get_Count() > 0 )
+	{
+		m_Parameters("LUT")->asTable()->Assign(&LUT);
 
-	m_Parameters("COLORS_TYPE")->Set_Value(CLASSIFY_LUT);	// Lookup Table
+		DataObject_Changed();
 
-	Parameters_Changed();
+		m_Parameters("COLORS_TYPE")->Set_Value(CLASSIFY_LUT);	// Lookup Table
+
+		Parameters_Changed();
+	}
 }
 
 
@@ -783,21 +816,13 @@ wxString CWKSP_Grid::Get_Value(CSG_Point ptWorld, double Epsilon)
 			break;
 
 		default:
-			switch( Get_Grid()->Get_Type() )
+			if( ::SG_Get_Significant_Decimals(Value) > 0 )
+			{
+				s.Printf(wxT("%f%s"),      Value, Get_Grid()->Get_Unit());
+			}
+			else
 			{
-			case SG_DATATYPE_Byte:
-			case SG_DATATYPE_Char:
-			case SG_DATATYPE_Word:
-			case SG_DATATYPE_Short:
-			case SG_DATATYPE_DWord:
-			case SG_DATATYPE_Int:
 				s.Printf(wxT("%d%s"), (int)Value, Get_Grid()->Get_Unit());
-				break;
-
-			case SG_DATATYPE_Float:	default:
-			case SG_DATATYPE_Double:
-				s.Printf(wxT("%f%s"), Value, Get_Grid()->Get_Unit());
-				break;
 			}
 			break;
 
@@ -916,7 +941,7 @@ bool CWKSP_Grid::Edit_On_Mouse_Up(CSG_Point Point, double ClientToWorld, int Key
 				{
 					if( !Get_Grid()->is_NoData(m_xSel + x, m_ySel + ny - 1 - y) )
 					{
-						pRecord->Set_Value(x, Get_Grid()->asDouble(m_xSel + x, m_ySel + ny - 1 - y, false));
+						pRecord->Set_Value(x, Get_Grid()->asDouble(m_xSel + x, m_ySel + ny - 1 - y));
 					}
 					else
 					{
@@ -1025,27 +1050,39 @@ bool CWKSP_Grid::_Edit_Del_Selection(void)
 //---------------------------------------------------------
 bool CWKSP_Grid::Fit_Color_Range(void)
 {
-	double		zMin, zMax;
-
-	int		Method	= g_pData->Get_Parameter("GRID_COLORS_FIT")->asInt();
-
-	if( Method == 0 )
+	switch( g_pData->Get_Parameter("GRID_COLORS_FIT")->asInt() )
 	{
-		zMin	= Get_Grid()->Get_ZMin(true);
-		zMax	= Get_Grid()->Get_ZMax(true);
+	default:
+		{
+			return( Set_Color_Range(
+				Get_Grid()->Get_ZMin(),
+				Get_Grid()->Get_ZMax())
+			);
+		}
+
+	case  1:
+		{
+			double	d	= g_pData->Get_Parameter("GRID_COLORS_FIT_STDDEV")->asDouble();
+
+			double	min	= Get_Grid()->Get_Mean() - Get_Grid()->Get_StdDev() * d;
+			double	max	= Get_Grid()->Get_Mean() + Get_Grid()->Get_StdDev() * d;
+
+			return( Set_Color_Range(
+				min < Get_Grid()->Get_ZMin() ? Get_Grid()->Get_ZMin() : min,
+				max > Get_Grid()->Get_ZMax() ? Get_Grid()->Get_ZMax() : max)
+			);
+		}
+
+	case  2:
+		{
+			double	d	= g_pData->Get_Parameter("GRID_COLORS_FIT_PCTL")->asDouble();
+
+			return( Set_Color_Range(
+				Get_Grid()->Get_Percentile(        d),
+				Get_Grid()->Get_Percentile(100.0 - d))
+			);
+		}
 	}
-	else
-	{
-		double	d	= g_pData->Get_Parameter("GRID_COLORS_FIT_STDDEV")->asDouble();
-
-		zMin	= Get_Grid()->Get_ArithMean(true) - Get_Grid()->Get_StdDev(true) * d;
-		zMax	= Get_Grid()->Get_ArithMean(true) + Get_Grid()->Get_StdDev(true) * d;
-
-		if( zMin < Get_Grid()->Get_ZMin(true) )	zMin	= Get_Grid()->Get_ZMin(true);
-		if( zMax > Get_Grid()->Get_ZMax(true) )	zMax	= Get_Grid()->Get_ZMax(true);
-	}
-
-	return( Set_Color_Range(zMin, zMax) );
 }
 
 //---------------------------------------------------------
@@ -1056,13 +1093,14 @@ bool CWKSP_Grid::Fit_Color_Range(CSG_Rect rWorld)
 		return( false );
 	}
 
-	int		xMin	= Get_Grid()->Get_System().Get_xWorld_to_Grid(rWorld.Get_XMin());
-	int		yMin	= Get_Grid()->Get_System().Get_yWorld_to_Grid(rWorld.Get_YMin());
-	int		xMax	= Get_Grid()->Get_System().Get_xWorld_to_Grid(rWorld.Get_XMax());
-	int		yMax	= Get_Grid()->Get_System().Get_yWorld_to_Grid(rWorld.Get_YMax());
+	int	xMin	= Get_Grid()->Get_System().Get_xWorld_to_Grid(rWorld.Get_XMin());
+	int	yMin	= Get_Grid()->Get_System().Get_yWorld_to_Grid(rWorld.Get_YMin());
+	int	xMax	= Get_Grid()->Get_System().Get_xWorld_to_Grid(rWorld.Get_XMax());
+	int	yMax	= Get_Grid()->Get_System().Get_yWorld_to_Grid(rWorld.Get_YMax());
 
-	double	zMin	= 1.0;
-	double	zMax	= 0.0;
+	int	Method	= g_pData->Get_Parameter("GRID_COLORS_FIT")->asInt();
+
+	CSG_Simple_Statistics	s(Method == 2);
 
 	for(int y=yMin; y<=yMax; y++)
 	{
@@ -1070,16 +1108,48 @@ bool CWKSP_Grid::Fit_Color_Range(CSG_Rect rWorld)
 		{
 			if( Get_Grid()->is_InGrid(x, y) )
 			{
-				double	z	= Get_Grid()->asDouble(x, y);
-
-				if( zMin > zMax )	{	zMin	= zMax	= z;	}
-				else if( z < zMin )	{	zMin	= z;			}
-				else if( z > zMax )	{	zMax	= z;			}
+				s	+= Get_Grid()->asDouble(x, y);
 			}
 		}
 	}
 
-	return( Set_Color_Range(zMin, zMax) );
+	if( s.Get_Count() > 0 )
+	{
+		switch( Method )
+		{
+		default:
+			{
+				return( Set_Color_Range(
+					s.Get_Minimum(),
+					s.Get_Maximum())
+				);
+			}
+
+		case  1:
+			{
+				double	d	= g_pData->Get_Parameter("GRID_COLORS_FIT_STDDEV")->asDouble();
+
+				return( Set_Color_Range(
+					s.Get_Mean() - s.Get_StdDev() * d,
+					s.Get_Mean() + s.Get_StdDev() * d)
+				);
+			}
+
+		case  2:
+			{
+				CSG_Index	Index(s.Get_Count(), s.Get_Values());
+
+				double	d	= g_pData->Get_Parameter("GRID_COLORS_FIT_PCTL")->asDouble() / 100.0;
+
+				return( Set_Color_Range(
+					s.Get_Value(Index[(int)((    d) * s.Get_Count())]),
+					s.Get_Value(Index[(int)((1 - d) * s.Get_Count())]))
+				);
+			}
+		}
+	}
+
+	return( false );
 }
 
 
@@ -1356,7 +1426,7 @@ void CWKSP_Grid::_Draw_Grid_Line(CWKSP_Map_DC &dc_Map, int Interpolation, bool b
 	{
 		double	Value;
 
-		if( Get_Grid()->Get_Value(xMap, yMap, Value, Interpolation, false, bByteWise, true) )
+		if( Get_Grid()->Get_Value(xMap, yMap, Value, Interpolation, bByteWise, true) )
 		{
 			if( m_bOverlay == false )
 			{
@@ -1373,10 +1443,10 @@ void CWKSP_Grid::_Draw_Grid_Line(CWKSP_Map_DC &dc_Map, int Interpolation, bool b
 
 				c[0]	= (int)(255.0 * m_pClassify->Get_MetricToRelative(Value));
 
-				c[1]	= m_pOverlay[0] && m_pOverlay[0]->Get_Grid()->Get_Value(xMap, yMap, Value, Interpolation, false, false, true)
+				c[1]	= m_pOverlay[0] && m_pOverlay[0]->Get_Grid()->Get_Value(xMap, yMap, Value, Interpolation, false, true)
 						? (int)(255.0 * m_pOverlay[0]->m_pClassify->Get_MetricToRelative(Value)) : 255;
 
-				c[2]	= m_pOverlay[1] && m_pOverlay[1]->Get_Grid()->Get_Value(xMap, yMap, Value, Interpolation, false, false, true)
+				c[2]	= m_pOverlay[1] && m_pOverlay[1]->Get_Grid()->Get_Value(xMap, yMap, Value, Interpolation, false, true)
 						? (int)(255.0 * m_pOverlay[1]->m_pClassify->Get_MetricToRelative(Value)) : 255;
 
 				dc_Map.IMG_Set_Pixel(xDC, yDC, SG_GET_RGB(
@@ -1432,12 +1502,11 @@ void CWKSP_Grid::_Draw_Values(CWKSP_Map_DC &dc_Map)
 
 	//-----------------------------------------------------
 	int			ax, ay, bx, by, Decimals, Effect;
-	double		axDC, ayDC, dDC, zFactor;
+	double		axDC, ayDC, dDC;
 	wxColour	Effect_Color;
 	wxFont		Font;
 
 	dDC			= Get_Grid()->Get_Cellsize() * dc_Map.m_World2DC;
-	zFactor		= Get_Grid()->Get_ZFactor();
 	Decimals	= m_Parameters("VALUES_DECIMALS")->asInt();
 	Font		= Get_Font(m_Parameters("VALUES_FONT"));
 	Font.SetPointSize((int)(dDC * m_Parameters("VALUES_SIZE")->asDouble() / 100.0));
@@ -1496,7 +1565,7 @@ void CWKSP_Grid::_Draw_Values(CWKSP_Map_DC &dc_Map)
 
 				default:
 					Draw_Text(dc_Map.dc, TEXTALIGN_CENTER, (int)xDC, (int)yDC, wxString::Format(
-						wxT("%.*f"), Decimals, zFactor * Value
+						wxT("%.*f"), Decimals, Value
 					), Effect, Effect_Color);
 					break;
 				}
