@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: wksp_module.cpp 2102 2014-04-19 16:29:45Z reklov_w $
+ * Version $Id: wksp_module.cpp 2301 2014-10-21 08:52:29Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -62,6 +62,7 @@
 
 //---------------------------------------------------------
 #include <wx/utils.h>
+#include <wx/filename.h>
 
 #include "res_commands.h"
 #include "res_dialogs.h"
@@ -75,7 +76,6 @@
 
 #include "wksp_module_manager.h"
 #include "wksp_module_library.h"
-#include "wksp_module_menu.h"
 #include "wksp_module.h"
 
 
@@ -100,39 +100,6 @@ CWKSP_Module::CWKSP_Module(CSG_Module *pModule, const wxString &Menu_Library)
 {
 	m_pModule	= pModule;
 	m_Menu_ID	= -1;
-	m_Menu_Path	.Clear();
-
-	//-----------------------------------------------------
-	wxString	Menu_Module	= m_pModule->Get_MenuPath().w_str();
-
-	if( Menu_Module.Length() > 2 && Menu_Module[1] == ':' )
-	{
-		if( Menu_Module[0] == 'A' || Menu_Module[0] == 'a' )		// absolute menu path, overwrites library's default menu path
-		{
-			m_Menu_Path.Printf(wxT("%s"), Menu_Module.AfterFirst(':'));
-		}
-		else //if( Menu_Module[0] == 'R' || Menu_Module[0] == 'r' )	// menu path explicitly declared as relative to library's default menu path
-		{
-			Menu_Module	= Menu_Module.AfterFirst(':');
-		}
-	}
-
-	//-----------------------------------------------------
-	if( m_Menu_Path.Length() == 0 )	// menu path is relative to library's default menu
-	{
-		if( Menu_Library.Length() > 0 && Menu_Module.Length() > 0 )
-		{
-			m_Menu_Path.Printf(wxT("%s|%s"), Menu_Library, Menu_Module);
-		}
-		else if( Menu_Library.Length() > 0 )
-		{
-			m_Menu_Path.Printf(wxT("%s"), Menu_Library);
-		}
-		else if( Menu_Module.Length() > 0 )
-		{
-			m_Menu_Path.Printf(wxT("%s"), Menu_Module);
-		}
-	}
 }
 
 //---------------------------------------------------------
@@ -169,22 +136,80 @@ wxString CWKSP_Module::Get_Name(void)
 }
 
 //---------------------------------------------------------
-void CWKSP_Module::Set_File_Name(const wxString &File_Name)
+wxString CWKSP_Module::Get_Menu_Path(void)
 {
-	m_File_Name = File_Name;
+	//-----------------------------------------------------
+	wxString	Menu	= m_pModule->Get_MenuPath().c_str();
+
+	if( Menu.Length() > 1 && Menu[1] == ':' )
+	{
+		if( Menu[0] == 'A' || Menu[0] == 'a' )		// absolute menu path, overwrites library's default menu path
+		{
+			return( Menu.AfterFirst(':') );
+		}
+
+		Menu	= Menu.AfterFirst(':');	// Menu[0] == 'R' || Menu[0] == 'r'	// menu path explicitly declared as relative to library's default menu path
+	}
+
+	//-----------------------------------------------------
+	wxString	Root	= ((CWKSP_Module_Library *)Get_Manager())->Get_Library()->Get_Menu().c_str();
+
+	if( Root.IsEmpty() )
+	{
+		return( Menu );
+	}
+
+	if( Menu.IsEmpty() )
+	{
+		return( Root );
+	}
+
+	return( Root + "|" + Menu );
+}
+
+//---------------------------------------------------------
+wxString CWKSP_Module::Get_File_Name(void)
+{
+	return( m_pModule->Get_File_Name().c_str() );
 }
 
 //---------------------------------------------------------
 wxString CWKSP_Module::Get_Description(void)
 {
-	wxString	Description;
+	//-----------------------------------------------------
+	if( !Get_File_Name().IsEmpty() )
+	{
+		CSG_String	Description;
+		CSG_File	Stream;
+
+		wxFileName	FileName(Get_File_Name());
+		FileName.AppendDir	(FileName.GetName());
+		FileName.SetName	(wxString::Format("%s_%02d", FileName.GetName().c_str(), Get_Index()));
+
+		FileName.SetExt		("html");
+
+		if( Stream.Open(FileName.GetFullPath().wc_str(), SG_FILE_R) && Stream.Read(Description, Stream.Length()) )
+		{
+			return( Description.c_str() );
+		}
+
+		FileName.SetExt		("htm");
+
+		if( Stream.Open(FileName.GetFullPath().wc_str(), SG_FILE_R) && Stream.Read(Description, Stream.Length()) )
+		{
+			return( Description.c_str() );
+		}
+	}
+
+	//-----------------------------------------------------
+	wxString	Menu(Get_Menu_Path()), Description;
 
 	if( g_pModules->Get_Parameter("HELP_SOURCE")->asInt() == 1 )
 	{
-		Description	= Get_Online_Module_Description(((CWKSP_Module_Library *)Get_Manager())->Get_File_Name(), Get_Module()->Get_ID());
+		Description	= Get_Online_Module_Description(((CWKSP_Module_Library *)Get_Manager())->Get_File_Name(), Get_Module()->Get_ID().c_str());
 	}
 
-	return( m_pModule->Get_Summary(true, &m_Menu_Path, &Description).c_str() );
+	return( m_pModule->Get_Summary(true, &Menu, &Description).c_str() );
 }
 
 //---------------------------------------------------------
@@ -199,6 +224,15 @@ wxMenu * CWKSP_Module::Get_Menu(void)
 	pMenu->AppendSeparator();
 
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MODULES_SAVE_SCRIPT);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MODULES_SAVE_TO_CLIPBOARD);
+
+	if( m_pModule->Get_Type() == MODULE_TYPE_Chain )
+	{
+		pMenu->AppendSeparator();
+
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_MODULES_CHAIN_RELOAD);
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_MODULES_CHAIN_EDIT);
+	}
 
 	return( pMenu );
 }
@@ -229,7 +263,28 @@ bool CWKSP_Module::On_Command(int Cmd_ID)
 		break;
 
 	case ID_CMD_MODULES_SAVE_SCRIPT:
-		_Save_Script();
+		_Save_to_Script();
+		break;
+
+	case ID_CMD_MODULES_SAVE_TO_CLIPBOARD:
+		_Save_to_Clipboard();
+		break;
+
+	case ID_CMD_MODULES_CHAIN_RELOAD:
+		if( m_pModule->Get_Type() == MODULE_TYPE_Chain
+		&&  g_pModules->Open(m_pModule->Get_File_Name().c_str())
+		&&  g_pACTIVE->Get_Active() == this )
+		{
+			g_pACTIVE->Set_Active(NULL);
+			g_pACTIVE->Set_Active(this);
+		}
+		break;
+
+	case ID_CMD_MODULES_CHAIN_EDIT:
+		if( m_pModule->Get_Type() == MODULE_TYPE_Chain )
+		{
+			Open_Application(m_pModule->Get_File_Name().c_str(), "txt");
+		}
 		break;
 	}
 
@@ -244,198 +299,426 @@ bool CWKSP_Module::On_Command(int Cmd_ID)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-void CWKSP_Module::_Save_Script(void)
+void CWKSP_Module::Set_Menu_ID(int aMenu_ID)
+{
+	m_Menu_ID	= aMenu_ID;
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CWKSP_Module::is_Interactive(void)
+{
+	return( m_pModule->is_Interactive() );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Module::is_Executing(void)
+{
+	return( m_pModule->is_Executing() );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+#define MSG_ADD(s)			MSG_General_Add  (s, true, true);\
+							MSG_Execution_Add(s, true, true);
+
+#define MSG_ADD2(b, s1, s2)	MSG_General_Add  (b ? s1 : s2, true, true, b ? SG_UI_MSG_STYLE_SUCCESS : SG_UI_MSG_STYLE_FAILURE);\
+							MSG_Execution_Add(b ? s1 : s2, true, true, b ? SG_UI_MSG_STYLE_SUCCESS : SG_UI_MSG_STYLE_FAILURE);
+
+//---------------------------------------------------------
+bool CWKSP_Module::Execute(bool bDialog)
+{
+	bool	bResult	= false;
+
+	//-----------------------------------------------------
+	if( g_pModule )
+ 	{
+		if( g_pModule == this )
+		{
+			if( g_pModule->is_Executing() )
+			{
+				if( !bDialog || DLG_Message_Confirm(_TL("Shall execution be stopped?"), _TL("Tool Execution")) )
+				{
+					PROCESS_Set_Okay(false);
+				}
+			}
+			else if( m_pModule->is_Interactive() )
+			{
+				if( !bDialog || DLG_Message_Confirm(_TL("Shall execution be stopped?"), _TL("Tool Execution")) )
+				{
+					bResult		= ((CSG_Module_Interactive *)m_pModule)->Execute_Finish();
+					g_pModule	= NULL;
+
+					PROCESS_Set_Okay(true);
+
+					MSG_ADD2(bResult,
+						_TL("Interactive tool execution has been stopped"),
+						_TL("Interactive tool execution failed")
+					);
+				}
+			}
+		}
+		else
+		{
+			DLG_Message_Show(_TL("Can't execute a tool while another runs"), _TL("Tool Execution"));
+		}
+	}
+
+	//-----------------------------------------------------
+	else
+	{
+		g_pModule	= this;
+
+		if( m_pModule->On_Before_Execution() && (!bDialog || DLG_Parameters(m_pModule->Get_Parameters())) )
+		{
+			g_pModules->Set_Recently_Used(this);
+
+			MSG_General_Add_Line();
+			MSG_Execution_Add_Line();
+			MSG_ADD(wxString::Format(wxT("%s: %s"), _TL("Executing tool"), m_pModule->Get_Name().c_str()));
+
+			STATUSBAR_Set_Text(m_pModule->Get_Name().w_str());
+
+			bResult		= m_pModule->Execute();
+
+			g_pACTIVE->Get_Parameters()->Update_Parameters(m_pModule->Get_Parameters(), false);
+
+			if( m_pModule->is_Interactive() )
+			{
+				MSG_ADD2(bResult,
+					_TL("Interactive tool execution has been started"),
+					_TL("Interactive tool execution failed")
+				);
+			}
+			else
+			{
+				MSG_ADD2(bResult,
+					_TL("Tool execution succeeded"),
+					_TL("Tool execution failed")
+				);
+			}
+
+			if( g_pModules && g_pModules->Do_Beep() )	{	Do_Beep();	}
+		}
+
+		if( !m_pModule->is_Interactive() || !bResult )
+		{
+			g_pModule	= NULL;
+		}
+	}
+
+	//-----------------------------------------------------
+	return( bResult );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Module::Execute(CSG_Point ptWorld, TSG_Module_Interactive_Mode Mode, int Keys)
+{
+	if( g_pModule == this && m_pModule->is_Interactive() )
+	{
+		return( ((CSG_Module_Interactive *)m_pModule)->Execute_Position(ptWorld, Mode, Keys) );
+	}
+
+	return( false );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+#include <wx/clipbrd.h>
+
+//---------------------------------------------------------
+void CWKSP_Module::_Save_to_Clipboard(void)
+{
+	CSG_MetaData	Tool;	Tool.Set_Name("tool");
+
+	Tool.Add_Property("library", m_pModule->Get_Library());
+	Tool.Add_Property("module" , m_pModule->Get_ID     ());
+	Tool.Add_Property("name"   , m_pModule->Get_Name   ());
+
+	_Save_to_Clipboard(Tool, m_pModule->Get_Parameters());
+
+	for(int i=0; i<m_pModule->Get_Parameters_Count(); i++)
+	{
+		_Save_to_Clipboard(Tool, m_pModule->Get_Parameters());
+	}
+
+	if( wxTheClipboard->Open() )
+	{
+		CSG_MetaData	Tools;	Tools.Set_Name("toolchain");
+
+		Tools.Add_Property("saga-version", SAGA_VERSION);
+
+		Tools.Add_Child("group");
+		Tools.Add_Child("identifier");
+		Tools.Add_Child("name");
+		Tools.Add_Child("author");
+		Tools.Add_Child("description");
+		Tools.Add_Child("menu");
+		Tools.Add_Child("parameters");
+		Tools.Add_Child("tools")->Add_Child(Tool);
+
+		CSG_String	s(Tools.asText(1));
+
+		wxTheClipboard->SetData(new wxTextDataObject(s.c_str()));
+		wxTheClipboard->Close();
+	}
+}
+
+//---------------------------------------------------------
+void CWKSP_Module::_Save_to_Clipboard(CSG_MetaData &Tool, CSG_Parameters *pParameters)
+{
+	for(int iParameter=0; iParameter<pParameters->Get_Count(); iParameter++)
+	{
+		CSG_Parameter	*p	= pParameters->Get_Parameter(iParameter);
+
+		if( !p->is_Enabled() )
+		{
+			continue;
+		}
+
+		CSG_MetaData	*pChild	= NULL;
+
+		switch( p->Get_Type() )
+		{
+		case PARAMETER_TYPE_Parameters  :
+			_Save_to_Clipboard(Tool, p->asParameters());
+			break;
+
+		case PARAMETER_TYPE_Bool        :
+		case PARAMETER_TYPE_Int         :
+		case PARAMETER_TYPE_Double      :
+		case PARAMETER_TYPE_Degree      :
+		case PARAMETER_TYPE_Range       :
+		case PARAMETER_TYPE_String      :
+		case PARAMETER_TYPE_Text        :
+		case PARAMETER_TYPE_FilePath    :
+		case PARAMETER_TYPE_Table_Field :
+		case PARAMETER_TYPE_Table_Fields:
+			pChild	= Tool.Add_Child("option", p->asString());
+			break;
+
+		case PARAMETER_TYPE_Choice      :
+			pChild	= Tool.Add_Child("option", p->asInt());
+			break;
+
+		case PARAMETER_TYPE_Grid_System :
+			if( p->Get_Children_Count() == 0 )
+			{
+				pChild	= Tool.Add_Child("option", p->asString());
+			}
+			break;
+
+		default:
+			if( p->is_Input() )
+			{
+				pChild	= Tool.Add_Child("input");
+				pChild->Set_Content(p->is_Optional() ? "input_optional" : "input");
+			}
+			else if( p->is_Output() )
+			{
+				pChild	= Tool.Add_Child("output");
+				pChild->Set_Content("output");
+			}
+			break;
+		}
+
+		if( pChild )
+		{
+			pChild->Add_Property("parms", pParameters->Get_Identifier());
+			pChild->Add_Property("id"   , p          ->Get_Identifier());
+		}
+	}
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+void CWKSP_Module::_Save_to_Script(void)
 {
 	wxString	FileName;
 
-	if( DLG_Save(FileName, _TL("Create Script Command File"), SG_T("DOS Batch Script (*.bat)|*.bat|Bash Script (*.sh)|*.sh|Python Script (*.py)|*.py")) )
+	if( !DLG_Save(FileName, _TL("Create Script Command File"), SG_T("DOS Batch Script (*.bat)|*.bat|Bash Script (*.sh)|*.sh|Python Script (*.py)|*.py")) )
 	{
-		CSG_File	File;
-		CSG_String	Command;
+		return;
+	}
 
-		if(      SG_File_Cmp_Extension(FileName, SG_T("bat")) )
+	CSG_String	s;
+
+	//-----------------------------------------------------
+	if( SG_File_Cmp_Extension(FileName, SG_T("bat")) )
+	{
+		s	+= "@ECHO OFF\n\n";
+		s	+= "REM SET SAGA_MLB=C:\\SAGA\\Modules\n";
+		s	+= "REM SET PATH=%PATH%;C:\\SAGA\n\n";
+		s	+= "REM Tool: ";
+		s	+= m_pModule->Get_Name() + "\n\n";
+		s	+= "saga_cmd ";
+		s	+= m_pModule->Get_Library() + " " + m_pModule->Get_ID() + "\n";
+
+		_Save_to_Script_CMD(s, m_pModule->Get_Parameters());
+
+		for(int i=0; i<m_pModule->Get_Parameters_Count(); i++)
 		{
-			Command	+= SG_T("@ECHO OFF\n\n");
-
-			Command	+= SG_T("REM SET SAGA_MLB=C:\\SAGA\\Modules\n");
-			Command	+= SG_T("REM SET PATH=%PATH%;C:\\SAGA\n\n");
-
-			Command	+= SG_T("saga_cmd ");
-
-			#ifdef _SAGA_MSW
-			Command	+= SG_File_Get_Name(((CWKSP_Module_Library *)Get_Manager())->Get_File_Name(), false);
-			#else
-			Command	+= SG_File_Get_Name(((CWKSP_Module_Library *)Get_Manager())->Get_File_Name(), false).Remove(0, 3);
-			#endif
-
-			Command	+= SG_T(" \"");
-			Command	+= m_pModule->Get_Name();
-			Command	+= SG_T("\"");
-
-			_Save_Script_CMD(Command, m_pModule->Get_Parameters());
-
-			for(int i=0; i<m_pModule->Get_Parameters_Count(); i++)
-			{
-				_Save_Script_CMD(Command, m_pModule->Get_Parameters(i));
-			}
-
-			Command	+= SG_T("\n\nPAUSE\n");
-		}
-		if(      SG_File_Cmp_Extension(FileName, SG_T("sh")) )
-		{
-			Command	+= SG_T("#!/bin/bash\n\n");
-
-			Command	+= SG_T("# export SAGA_MLB=/usr/lib/saga\n\n");
-
-			Command	+= SG_T("saga_cmd ");
-
-			#ifdef _SAGA_MSW
-			Command	+= SG_File_Get_Name(((CWKSP_Module_Library *)Get_Manager())->Get_File_Name(), false);
-			#else
-			Command	+= SG_File_Get_Name(((CWKSP_Module_Library *)Get_Manager())->Get_File_Name(), false).Remove(0, 3);
-			#endif
-
-			Command	+= SG_T(" \"");
-			Command	+= m_pModule->Get_Name();
-			Command	+= SG_T("\"");
-
-			_Save_Script_CMD(Command, m_pModule->Get_Parameters());
-
-			for(int i=0; i<m_pModule->Get_Parameters_Count(); i++)
-			{
-				_Save_Script_CMD(Command, m_pModule->Get_Parameters(i));
-			}
-		}
-		else if( SG_File_Cmp_Extension(FileName, SG_T("py" )) )
-		{
-			#ifndef _SAGA_MSW
-			Command	+= SG_T("#! /usr/bin/env python\n");
-			#endif
-			Command	+= SG_T("# Python script template for SAGA tool execution (automatically created, experimental)\n\n");
-			Command	+= SG_T("import saga_api, sys, os\n");
-			Command	+= SG_T("\n");
-			Command	+= SG_T("##########################################\n");
-			Command	+= SG_T("def Call_SAGA_Module(fDEM):            # pass your input file(s) here\n");
-			Command	+= SG_T("\n");
-			Command	+= SG_T("    # ------------------------------------\n");
-			Command	+= SG_T("    # initialize input dataset(s)\n");
-			Command	+= SG_T("    dem    = saga_api.SG_Get_Data_Manager().Add_Grid(unicode(fDEM))\n");
-			Command	+= SG_T("    if dem == None or dem.is_Valid() == 0:\n");
-			Command	+= SG_T("        print 'ERROR: loading grid [' + fDEM + ']'\n");
-			Command	+= SG_T("        return 0\n");
-			Command	+= SG_T("\n");
-			Command	+= SG_T("    # ------------------------------------\n");
-			Command	+= SG_T("    # initialize output dataset(s)\n");
-			Command	+= SG_T("    outgrid = saga_api.SG_Get_Data_Manager().Add_Grid(dem.Get_System())\n");
-			Command	+= SG_T("\n");
-			Command	+= SG_T("    # ------------------------------------\n");
-			Command	+= SG_T("    # call module\n");
-//			Command	+= SG_T("    Library = saga_api.CSG_Module_Library()\n");
-//			Command	+= SG_T("    if Library.Create(saga_api.CSG_String('");
-//			Command	+= ((CWKSP_Module_Library *)Get_Manager())->Get_File_Name().wc_str();
-//			Command	+= SG_T("')) == 0:\n");
-//			Command	+= SG_T("        print 'unable to load SAGA tool library'\n");
-//			Command	+= SG_T("        return 0\n");
-//			Command	+= SG_T("\n");
-
-			#ifdef _SAGA_MSW
-			Command	+= CSG_String::Format(SG_T("    Module = saga_api.SG_Get_Module_Library_Manager().Get_Module('%s','%s')\n"), SG_File_Get_Name(((CWKSP_Module_Library *)Get_Manager())->Get_File_Name(), false).c_str(), m_pModule->Get_Name().c_str());
-			#else
-			Command	+= CSG_String::Format(SG_T("    Module = saga_api.SG_Get_Module_Library_Manager().Get_Module('%s','%s')\n"), SG_File_Get_Name(((CWKSP_Module_Library *)Get_Manager())->Get_File_Name(), false).Remove(0, 3).c_str(), m_pModule->Get_Name().c_str());
-			#endif
-
-			if( m_pModule->Get_Type() )
-			{
-				Command	+= SG_T("    Module.Get_Parameters().Get_Grid_System().Assign(dem.Get_System())\n");
-			}
-/*			switch( m_pModule->Get_Type() )
-			{
-			default:
-				Command	+= CSG_String::Format(SG_T("    Module = saga_api.SG_Get_Module_Library_Manager().Get_Module('%s')\n")		, m_pModule->Get_Name().c_str());
-				break;
-
-			case MODULE_TYPE_Grid:
-				Command	+= CSG_String::Format(SG_T("    Module = saga_api.SG_Get_Module_Library_Manager().Get_Module_Grid('%s')\n")	, m_pModule->Get_Name().c_str());
-				Command	+= SG_T("    Module.Get_Parameters().Get_Grid_System().Assign(dem.Get_System())\n");
-				break;
-			}*/
-
-			Command	+= SG_T("\n");
-			Command	+= SG_T("    Parms = Module.Get_Parameters() # default parameter list\n");
-			_Save_Script_Python(Command, m_pModule->Get_Parameters());
-
-			for(int i=0; i<m_pModule->Get_Parameters_Count(); i++)
-			{
-				Command	+= SG_T("\n");
-				Command	+= CSG_String::Format(SG_T("    Parms = Module.Get_Parameters(%d) # additional parameter list\n"), i);
-				_Save_Script_Python(Command, m_pModule->Get_Parameters(i));
-			}
-
-			Command	+= SG_T("\n");
-			Command	+= SG_T("    if Module.Execute() == 0:\n");
-			Command	+= SG_T("        print 'Module execution failed!'\n");
-			Command	+= SG_T("        return 0\n");
-			Command	+= SG_T("\n");
-			Command	+= SG_T("\n");
-			Command	+= SG_T("    print\n");
-			Command	+= SG_T("    print 'The module has been executed.'\n");
-			Command	+= SG_T("    print 'Now you would like to save your output datasets, please edit the script to do so.'\n");
-			Command	+= SG_T("    return 0                           # remove this line once you have edited the script\n");
-			Command	+= SG_T("\n");
-			Command	+= SG_T("\n");
-			Command	+= SG_T("    # ------------------------------------\n");
-			Command	+= SG_T("    # save results\n");
-			Command	+= SG_T("    path   = os.path.split(fDEM)[0]\n");
-			Command	+= SG_T("    if path == '':\n");
-			Command	+= SG_T("        path = './'\n");
-			Command	+= SG_T("    outgrid.Save(saga_api.CSG_String(path + '/outgrid'))\n");
-			Command	+= SG_T("\n");
-			Command	+= SG_T("    print\n");
-			Command	+= SG_T("    print 'Module successfully executed!'\n");
-			Command	+= SG_T("    return 1\n");
-			Command	+= SG_T("\n");
-			Command	+= SG_T("\n");
-			Command	+= SG_T("##########################################\n");
-			Command	+= SG_T("if __name__ == '__main__':\n");
-			Command	+= SG_T("    print 'Python - Version ' + sys.version\n");
-			Command	+= SG_T("    print saga_api.SAGA_API_Get_Version()\n");
-			Command	+= SG_T("    print\n");
-			Command	+= CSG_String::Format(SG_T("    print 'Usage: %s <in: filename>'\n"), FileName.wc_str());
-			Command	+= SG_T("    print\n");
-			Command	+= SG_T("    print 'This is a simple template, please edit the script and add the necessary input and output file(s)!'\n");
-			Command	+= SG_T("    print 'We will exit the script for now.'\n");
-			Command	+= SG_T("    sys.exit()                         # remove this line once you have edited the script\n");
-			Command	+= SG_T("    # This might look like this:\n");
-			Command	+= SG_T("    # fDEM    = sys.argv[1]\n");
-			Command	+= SG_T("    # if os.path.split(fDEM)[0] == '':\n");
-			Command	+= SG_T("    #    fDEM    = './' + fDEM\n");
-			Command	+= SG_T("    fDEM = './../test_data/test.sgrd'  # remove this line once you have edited the script\n");
-			Command	+= SG_T("\n\n");
-			Command	+= SG_T("    saga_api.SG_UI_Msg_Lock(1)\n");
-			Command	+= SG_T("    if os.name == 'nt':    # Windows\n");
-			Command	+= SG_T("        os.environ['PATH'] = os.environ['PATH'] + ';' + os.environ['SAGA'] + '/bin/saga_vc_Win32/dll'\n");
-			Command	+= SG_T("        saga_api.SG_Get_Module_Library_Manager().Add_Directory(os.environ['SAGA'] + '/bin/saga_vc_Win32/modules', 0)\n");
-			Command	+= SG_T("    else:                  # Linux\n");
-			Command	+= SG_T("        saga_api.SG_Get_Module_Library_Manager().Add_Directory(os.environ['SAGA_MLB'], 0)\n");
-			Command	+= SG_T("    saga_api.SG_UI_Msg_Lock(0)\n");
-			Command	+= SG_T("\n");
-			Command	+= SG_T("    Call_SAGA_Module(fDEM)             # pass your input file(s) here\n");
-//			Command	+= SG_T("    else:\n");
-//			Command	+= SG_T("        in__grid    = saga_api.SG_Create_Grid(saga_api.CSG_String(sys.argv[1]))\n");
-//			Command	+= SG_T("        out_grid    = saga_api.SG_Create_Grid(grid_in.Get_System())\n");
-//			Command	+= SG_T("        in__shapes  = saga_api.SG_Create_Shapes(saga_api.CSG_String(sys.argv[3]))\n");
-//			Command	+= SG_T("        out_shapes  = saga_api.SG_Create_Shapes()\n");
-//			Command	+= SG_T("\n");
-//			Command	+= SG_T("        if Call_SAGA_Module(in__grid, out_grid, in__shapes, out_shapes) != 0:\n");
-//			Command	+= SG_T("            grid_out  .Save(saga_api.CSG_String(sys.argv[2]))\n");
-//			Command	+= SG_T("            shapes_out.Save(saga_api.CSG_String(sys.argv[4]))\n");
+			_Save_to_Script_CMD(s, m_pModule->Get_Parameters(i));
 		}
 
-		if( File.Open(&FileName, SG_FILE_W, false) && Command.Length() > 0 )
+		s	+= "\n\nPAUSE\n";
+	}
+
+	//-----------------------------------------------------
+	if( SG_File_Cmp_Extension(FileName, SG_T("sh")) )
+	{
+		s	+= "#!/bin/bash\n\n";
+		s	+= "# export SAGA_MLB=/usr/lib/saga\n\n";
+		s	+= "# tool: ";
+		s	+= m_pModule->Get_Name() + "\n\n";
+		s	+= "saga_cmd ";
+		s	+= m_pModule->Get_Library() + " " + m_pModule->Get_ID() + "\n";
+
+		_Save_to_Script_CMD(s, m_pModule->Get_Parameters());
+
+		for(int i=0; i<m_pModule->Get_Parameters_Count(); i++)
 		{
-			File.Write(Command);
+			_Save_to_Script_CMD(s, m_pModule->Get_Parameters(i));
 		}
 	}
+
+	//-----------------------------------------------------
+	if( SG_File_Cmp_Extension(FileName, SG_T("py")) )
+	{
+		#ifndef _SAGA_MSW
+		s	+= "#! /usr/bin/env python\n";
+		#endif
+		s	+= "# Python script template for SAGA tool execution (automatically created, experimental)\n\n";
+		s	+= "import saga_api, sys, os\n";
+		s	+= "\n";
+		s	+= "##########################################\n";
+		s	+= "def Call_SAGA_Module(fDEM):            # pass your input file(s) here\n";
+		s	+= "\n";
+		s	+= "    # ------------------------------------\n";
+		s	+= "    # initialize input dataset(s)\n";
+		s	+= "    dem    = saga_api.SG_Get_Data_Manager().Add_Grid(unicode(fDEM))\n";
+		s	+= "    if dem == None or dem.is_Valid() == 0:\n";
+		s	+= "        print 'ERROR: loading grid [' + fDEM + ']'\n";
+		s	+= "        return 0\n";
+		s	+= "\n";
+		s	+= "    # ------------------------------------\n";
+		s	+= "    # initialize output dataset(s)\n";
+		s	+= "    outgrid = saga_api.SG_Get_Data_Manager().Add_Grid(dem.Get_System())\n";
+		s	+= "\n";
+		s	+= "    # ------------------------------------\n";
+		s	+= "    # call module: ";
+		s	+= m_pModule->Get_Name() + "\n";
+		s	+= "    Module = saga_api.SG_Get_Module_Library_Manager().Get_Module('";
+		s	+= m_pModule->Get_Library() + "','" + m_pModule->Get_ID() + "')\n";
+
+		if( m_pModule->Get_Type() == MODULE_TYPE_Grid )
+		{
+			s	+= "    Module.Get_Parameters().Get_Grid_System().Assign(dem.Get_System())\n";
+		}
+
+		s	+= "\n";
+		s	+= "    Parms = Module.Get_Parameters() # default parameter list\n";
+
+		//-------------------------------------------------
+		_Save_to_Script_Python(s, m_pModule->Get_Parameters());
+
+		for(int i=0; i<m_pModule->Get_Parameters_Count(); i++)
+		{
+			s	+= "\n";
+			s	+= CSG_String::Format("    Parms = Module.Get_Parameters(%d) # additional parameter list\n", i);
+
+			_Save_to_Script_Python(s, m_pModule->Get_Parameters(i));
+		}
+
+		//-------------------------------------------------
+		s	+= "\n";
+		s	+= "    if Module.Execute() == 0:\n";
+		s	+= "        print 'Module execution failed!'\n";
+		s	+= "        return 0\n";
+		s	+= "\n";
+		s	+= "    print\n";
+		s	+= "    print 'The module has been executed.'\n";
+		s	+= "    print 'Now you would like to save your output datasets, please edit the script to do so.'\n";
+		s	+= "    return 0                           # remove this line once you have edited the script\n";
+		s	+= "\n";
+		s	+= "    # ------------------------------------\n";
+		s	+= "    # save results\n";
+		s	+= "    path   = os.path.split(fDEM)[0]\n";
+		s	+= "    if path == '':\n";
+		s	+= "        path = './'\n";
+		s	+= "    outgrid.Save(saga_api.CSG_String(path + '/outgrid'))\n";
+		s	+= "\n";
+		s	+= "    print\n";
+		s	+= "    print 'Module successfully executed!'\n";
+		s	+= "    return 1\n";
+		s	+= "\n";
+		s	+= "##########################################\n";
+		s	+= "if __name__ == '__main__':\n";
+		s	+= "    print 'Python - Version ' + sys.version\n";
+		s	+= "    print saga_api.SAGA_API_Get_Version()\n";
+		s	+= "    print\n";
+		s	+= CSG_String::Format("    print 'Usage: %s <in: filename>'\n", FileName.wc_str());
+		s	+= "    print\n";
+		s	+= "    print 'This is a simple template, please edit the script and add the necessary input and output file(s)!'\n";
+		s	+= "    print 'We will exit the script for now.'\n";
+		s	+= "    sys.exit()                         # remove this line once you have edited the script\n";
+		s	+= "    # This might look like this:\n";
+		s	+= "    # fDEM    = sys.argv[1]\n";
+		s	+= "    # if os.path.split(fDEM)[0] == '':\n";
+		s	+= "    #    fDEM    = './' + fDEM\n";
+		s	+= "    fDEM = './../test_data/test.sgrd'  # remove this line once you have edited the script\n";
+		s	+= "\n\n";
+		s	+= "    saga_api.SG_UI_Msg_Lock(1)\n";
+		s	+= "    if os.name == 'nt':    # Windows\n";
+		s	+= "        os.environ['PATH'] = os.environ['PATH'] + ';' + os.environ['SAGA'] + '/bin/saga_vc_Win32/dll'\n";
+		s	+= "        saga_api.SG_Get_Module_Library_Manager().Add_Directory(os.environ['SAGA'] + '/bin/saga_vc_Win32/modules', 0)\n";
+		s	+= "    else:                  # Linux\n";
+		s	+= "        saga_api.SG_Get_Module_Library_Manager().Add_Directory(os.environ['SAGA_MLB'], 0)\n";
+		s	+= "    saga_api.SG_UI_Msg_Lock(0)\n";
+		s	+= "\n";
+		s	+= "    Call_SAGA_Module(fDEM)             # pass your input file(s) here\n";
+	//	s	+= "    else:\n";
+	//	s	+= "        in__grid    = saga_api.SG_Create_Grid(saga_api.CSG_String(sys.argv[1]))\n";
+	//	s	+= "        out_grid    = saga_api.SG_Create_Grid(grid_in.Get_System())\n";
+	//	s	+= "        in__shapes  = saga_api.SG_Create_Shapes(saga_api.CSG_String(sys.argv[3]))\n";
+	//	s	+= "        out_shapes  = saga_api.SG_Create_Shapes()\n";
+	//	s	+= "\n";
+	//	s	+= "        if Call_SAGA_Module(in__grid, out_grid, in__shapes, out_shapes) != 0:\n";
+	//	s	+= "            grid_out  .Save(saga_api.CSG_String(sys.argv[2]))\n";
+	//	s	+= "            shapes_out.Save(saga_api.CSG_String(sys.argv[4]))\n";
+	}
+
+	//-----------------------------------------------------
+	CSG_File	File;
+
+	if( File.Open(&FileName, SG_FILE_W, false) && s.Length() > 0 )
+	{
+		File.Write(s);
+	}
 }
 
 //---------------------------------------------------------
@@ -448,12 +731,17 @@ void CWKSP_Module::_Save_Script(void)
 #define GET_ID2(p, s)	CSG_String::Format(SG_T("%s_%s"), GET_ID1(p), s).c_str()
 
 //---------------------------------------------------------
-void CWKSP_Module::_Save_Script_CMD(CSG_String &Command, CSG_Parameters *pParameters)
+void CWKSP_Module::_Save_to_Script_CMD(CSG_String &Command, CSG_Parameters *pParameters)
 {
 	for(int iParameter=0; iParameter<pParameters->Get_Count(); iParameter++)
 	{
 		CSG_Parameter	*p	= pParameters->Get_Parameter(iParameter);
 
+		if( !p->is_Enabled() )
+		{
+			continue;
+		}
+
 		switch( p->Get_Type() )
 		{
 		default:
@@ -546,12 +834,17 @@ void CWKSP_Module::_Save_Script_CMD(CSG_String &Command, CSG_Parameters *pParame
 }
 
 //---------------------------------------------------------
-void CWKSP_Module::_Save_Script_Python(CSG_String &Command, CSG_Parameters *pParameters)
+void CWKSP_Module::_Save_to_Script_Python(CSG_String &Command, CSG_Parameters *pParameters)
 {
 	for(int iParameter=0; iParameter<pParameters->Get_Count(); iParameter++)
 	{
 		CSG_Parameter	*p	= pParameters->Get_Parameter(iParameter);
 
+		if( !p->is_Enabled() )
+		{
+			continue;
+		}
+
 		switch( p->Get_Type() )
 		{
 		default:
@@ -643,149 +936,6 @@ void CWKSP_Module::_Save_Script_Python(CSG_String &Command, CSG_Parameters *pPar
 }
 
 
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-void CWKSP_Module::Set_Menu_ID(int aMenu_ID)
-{
-	m_Menu_ID	= aMenu_ID;
-}
-
-
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-bool CWKSP_Module::is_Interactive(void)
-{
-	return( m_pModule->is_Interactive() );
-}
-
-//---------------------------------------------------------
-bool CWKSP_Module::is_Executing(void)
-{
-	return( m_pModule->is_Executing() );
-}
-
-
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-#define MSG_ADD(s)			MSG_General_Add  (s, true, true);\
-							MSG_Execution_Add(s, true, true);
-
-#define MSG_ADD2(b, s1, s2)	MSG_General_Add  (b ? s1 : s2, true, true, b ? SG_UI_MSG_STYLE_SUCCESS : SG_UI_MSG_STYLE_FAILURE);\
-							MSG_Execution_Add(b ? s1 : s2, true, true, b ? SG_UI_MSG_STYLE_SUCCESS : SG_UI_MSG_STYLE_FAILURE);
-
-//---------------------------------------------------------
-bool CWKSP_Module::Execute(bool bDialog)
-{
-	bool	bResult	= false;
-
-	//-----------------------------------------------------
-	if( g_pModule )
- 	{
-		if( g_pModule == this )
-		{
-			if( g_pModule->is_Executing() )
-			{
-				if( !bDialog || DLG_Message_Confirm(_TL("Shall execution be stopped?"), _TL("Tool Execution")) )
-				{
-					PROCESS_Set_Okay(false);
-				}
-			}
-			else if( m_pModule->is_Interactive() )
-			{
-				if( !bDialog || DLG_Message_Confirm(_TL("Shall execution be stopped?"), _TL("Tool Execution")) )
-				{
-					bResult		= ((CSG_Module_Interactive *)m_pModule)->Execute_Finish();
-					g_pModule	= NULL;
-
-					PROCESS_Set_Okay(true);
-
-					MSG_ADD2(bResult,
-						_TL("Interactive tool execution has been stopped"),
-						_TL("Interactive tool execution failed")
-					);
-				}
-			}
-		}
-		else
-		{
-			DLG_Message_Show(_TL("Can't execute a tool while another runs"), _TL("Tool Execution"));
-		}
-	}
-
-	//-----------------------------------------------------
-	else
-	{
-		g_pModule	= this;
-
-		if( m_pModule->On_Before_Execution() && (!bDialog || DLG_Parameters(m_pModule->Get_Parameters())) )
-		{
-			g_pModules->Get_Menu_Modules()->Set_Recent(this);
-
-			MSG_General_Add_Line();
-			MSG_Execution_Add_Line();
-			MSG_ADD(wxString::Format(wxT("%s: %s"), _TL("Executing tool"), m_pModule->Get_Name().c_str()));
-
-			STATUSBAR_Set_Text(m_pModule->Get_Name().w_str());
-
-			bResult		= m_pModule->Execute();
-
-			g_pACTIVE->Get_Parameters()->Update_Parameters(m_pModule->Get_Parameters(), false);
-
-			if( m_pModule->is_Interactive() )
-			{
-				MSG_ADD2(bResult,
-					_TL("Interactive tool execution has been started"),
-					_TL("Interactive tool execution failed")
-				);
-			}
-			else
-			{
-				MSG_ADD2(bResult,
-					_TL("Tool execution succeeded"),
-					_TL("Tool execution failed")
-				);
-			}
-
-			if( g_pModules && g_pModules->Do_Beep() )	{	Do_Beep();	}
-		}
-
-		if( !m_pModule->is_Interactive() || !bResult )
-		{
-			g_pModule	= NULL;
-		}
-	}
-
-	//-----------------------------------------------------
-	return( bResult );
-}
-
-//---------------------------------------------------------
-bool CWKSP_Module::Execute(CSG_Point ptWorld, TSG_Module_Interactive_Mode Mode, int Keys)
-{
-	if( g_pModule == this && m_pModule->is_Interactive() )
-	{
-		return( ((CSG_Module_Interactive *)m_pModule)->Execute_Position(ptWorld, Mode, Keys) );
-	}
-
-	return( false );
-}
-
-
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
