@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: wksp_module_library.cpp 1994 2014-02-14 10:55:29Z oconrad $
+ * Version $Id: wksp_module_library.cpp 2281 2014-10-09 15:49:41Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -69,6 +69,7 @@
 
 #include "helper.h"
 
+#include "wksp_module_control.h"
 #include "wksp_module_manager.h"
 #include "wksp_module_library.h"
 #include "wksp_module.h"
@@ -85,31 +86,101 @@ CWKSP_Module_Library::CWKSP_Module_Library(CSG_Module_Library *pLibrary)
 {
 	m_pLibrary	= pLibrary;
 
+	_Add_Modules();
+}
+
+//---------------------------------------------------------
+CWKSP_Module_Library::~CWKSP_Module_Library(void)
+{
+	_Del_Modules();
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+void CWKSP_Module_Library::Update(void)
+{
+	int		i;
+
+	for(i=Get_Count()-1; i>=0; i--)	// first remove tools that are not available anymore
+	{
+		CWKSP_Module	*pItem	= Get_Module(i);
+
+		if( !m_pLibrary->Get_Module(pItem->Get_Module()->Get_Name()) )
+		{
+			Del_Item(pItem);
+
+			Get_Control()->Delete(pItem->GetId());
+		}
+	}
+
+	for(i=0; i<m_pLibrary->Get_Count(); i++)	// then add tools that are not yet present in the list
+	{
+		CSG_Module	*pModule	= m_pLibrary->Get_Module(i);
+
+		if( pModule != NULL && pModule != MLB_INTERFACE_SKIP_MODULE )
+		{
+			for(int j=0; j<Get_Count() && pModule; j++)
+			{
+				if( pModule == Get_Module(j)->Get_Module() )
+				{
+					Get_Control()->SetItemText(Get_Module(j)->GetId(), Get_Module(j)->Get_Name());	// just in case name has changed
+
+					pModule	= NULL;
+				}
+			}
+
+			if( pModule )
+			{
+				CWKSP_Module	*pItem	= new CWKSP_Module(pModule, m_pLibrary->Get_Menu().w_str());
+
+				Add_Item(pItem);
+
+				g_pModule_Ctrl->Add_Module(GetId(), pItem);
+			}
+		}
+	}
+
+	Get_Control()->SortChildren(GetId());
+}
+
+//---------------------------------------------------------
+void CWKSP_Module_Library::_Add_Modules(void)
+{
 	for(int i=0; i<m_pLibrary->Get_Count(); i++)
 	{
 		CSG_Module	*pModule	= m_pLibrary->Get_Module(i);
 
 		if( pModule != NULL && pModule != MLB_INTERFACE_SKIP_MODULE )
 		{
-			Add_Item(new CWKSP_Module(pModule, m_pLibrary->Get_Menu().w_str()));
+			CWKSP_Module	*pItem	= new CWKSP_Module(pModule, m_pLibrary->Get_Menu().w_str());
+
+			Add_Item(pItem);
 		}
 	}
 }
 
 //---------------------------------------------------------
-CWKSP_Module_Library::~CWKSP_Module_Library(void)
+void CWKSP_Module_Library::_Del_Modules(void)
 {
 	for(int i=Get_Count()-1; i>=0; i--)
 	{
 		CWKSP_Module	*pItem	= Get_Module(i);
-		Del_Item(pItem);
-		delete(pItem);
-	}
 
-	SG_Get_Module_Library_Manager().Del_Library(m_pLibrary);
+		Del_Item(pItem);
+
+	//	Get_Control()->Delete(pItem->GetId());
+	//	delete(pItem);
+	}
 }
 
 
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -156,9 +227,9 @@ wxString CWKSP_Module_Library::Get_Description(void)
 
 	for(int iModule=0; iModule<Get_Count(); iModule++)
 	{
-		s	+= wxString::Format(wxT("<li>[%d] %s</li>"),
-				Get_Module(iModule)->Get_Module()->Get_ID(),
-				Get_Module(iModule)->Get_Module()->Get_Name().w_str()
+		s	+= wxString::Format(wxT("<li>[%s] %s</li>"),
+				Get_Module(iModule)->Get_Module()->Get_ID  ().c_str(),
+				Get_Module(iModule)->Get_Module()->Get_Name().c_str()
 			);
 	}
 
@@ -197,6 +268,10 @@ bool CWKSP_Module_Library::On_Command(int Cmd_ID)
 	default:
 		return( CWKSP_Base_Manager::On_Command(Cmd_ID) );
 
+	case ID_CMD_WKSP_ITEM_CLOSE:
+		SG_Get_Module_Library_Manager().Del_Library(m_pLibrary);
+		break;
+
 	case ID_CMD_WKSP_ITEM_RETURN:
 		break;
 	}
