@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: wksp_shapes.cpp 2053 2014-03-18 09:47:18Z oconrad $
+ * Version $Id: wksp_shapes.cpp 2202 2014-08-26 13:24:07Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -427,11 +427,11 @@ void CWKSP_Shapes::On_Create_Parameters(void)
 		m_Parameters("NODE_EDIT")		, "EDIT_SNAP_LIST"			, _TL("Snap to..."),
 		_TL(""),
 		PARAMETER_INPUT
-	);
+	)->asShapesList()->Add_Item(m_pObject);
 
 	m_Parameters.Add_Value(
 		m_Parameters("EDIT_SNAP_LIST")	, "EDIT_SNAP_DIST"			, _TL("Snap Distance"),
-		_TL(""),
+		_TL("snap distance in screen units (pixels)"),
 		PARAMETER_TYPE_Int, 10, 0, true
 	);
 
@@ -575,19 +575,19 @@ int CWKSP_Shapes::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Paramete
 	{
 		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "OUTLINE") )
 		{
-			pParameters->Get_Parameter("OUTLINE_COLOR")->Set_Enabled(pParameter->asBool());
-			pParameters->Get_Parameter("OUTLINE_SIZE" )->Set_Enabled(pParameter->asBool());
+			pParameters->Set_Enabled("OUTLINE_COLOR", pParameter->asBool());
+			pParameters->Set_Enabled("OUTLINE_SIZE" , pParameter->asBool());
 		}
 
 		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "LABEL_ATTRIB") )
 		{
 			bool	Value	= pParameter->asInt() < Get_Shapes()->Get_Field_Count();
 
-			pParameters->Get_Parameter("LABEL_ATTRIB_FONT"     )->Set_Enabled(Value);
-			pParameters->Get_Parameter("LABEL_ATTRIB_SIZE_TYPE")->Set_Enabled(Value);
-			pParameters->Get_Parameter("LABEL_ATTRIB_PREC"     )->Set_Enabled(Value);
-			pParameters->Get_Parameter("LABEL_ATTRIB_SIZE_BY"  )->Set_Enabled(Value);
-			pParameters->Get_Parameter("LABEL_ATTRIB_EFFECT"   )->Set_Enabled(Value);
+			pParameters->Set_Enabled("LABEL_ATTRIB_FONT"     , Value);
+			pParameters->Set_Enabled("LABEL_ATTRIB_SIZE_TYPE", Value);
+			pParameters->Set_Enabled("LABEL_ATTRIB_PREC"     , Value);
+			pParameters->Set_Enabled("LABEL_ATTRIB_SIZE_BY"  , Value);
+			pParameters->Set_Enabled("LABEL_ATTRIB_EFFECT"   , Value);
 		}
 
 		if( !SG_STR_CMP(pParameter->Get_Identifier(), "LABEL_ATTRIB_SIZE_TYPE")
@@ -596,19 +596,19 @@ int CWKSP_Shapes::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Paramete
 			bool	Value	= pParameters->Get_Parameter("LABEL_ATTRIB_SIZE_TYPE")->asInt() != 0
 						||    pParameters->Get_Parameter("LABEL_ATTRIB_SIZE_BY"  )->asInt() < Get_Shapes()->Get_Field_Count();
 
-			pParameters->Get_Parameter("LABEL_ATTRIB_SIZE")->Set_Enabled(Value);
+			pParameters->Set_Enabled("LABEL_ATTRIB_SIZE", Value);
 		}
 
 		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "LABEL_ATTRIB_EFFECT") )
 		{
 			bool	Value	= pParameter->asInt() > 0;
 
-			pParameters->Get_Parameter("LABEL_ATTRIB_EFFECT_COLOR")->Set_Enabled(Value);
+			pParameters->Set_Enabled("LABEL_ATTRIB_EFFECT_COLOR", Value);
 		}
 
 		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "EDIT_SNAP_LIST") )
 		{
-			pParameters->Get_Parameter("EDIT_SNAP_DIST")->Set_Enabled(pParameter->asList()->Get_Count() > 0);
+			pParameters->Set_Enabled("EDIT_SNAP_DIST", pParameter->asList()->Get_Count() > 0);
 		}
 
 		if(	!SG_STR_CMP(pParameters->Get_Identifier(), "DISPLAY_CHART") )
@@ -619,10 +619,7 @@ int CWKSP_Shapes::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Paramete
 			{
 				s.Replace("FIELD_", "COLOR_");
 
-				if( pParameters->Get_Parameter(s) )
-				{
-					pParameters->Get_Parameter(s)->Set_Enabled(pParameter->asBool());
-				}
+				pParameters->Set_Enabled(s, pParameter->asBool());
 			}
 		}
 	}
@@ -1059,8 +1056,8 @@ void CWKSP_Shapes::_Draw_Shape(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int Sele
 
 		if( m_bVertices )
 		{
-			dc_Map.dc.SetPen  (*wxBLACK_PEN  );
-			dc_Map.dc.SetBrush(*wxWHITE_BRUSH);
+			wxPen	oldPen  (dc_Map.dc.GetPen  ());	dc_Map.dc.SetPen  (*wxBLACK_PEN  );
+			wxBrush	oldBrush(dc_Map.dc.GetBrush());	dc_Map.dc.SetBrush(*wxWHITE_BRUSH);
 
 			for(int iPart=0; iPart<pShape->Get_Part_Count(); iPart++)
 			{
@@ -1071,6 +1068,9 @@ void CWKSP_Shapes::_Draw_Shape(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int Sele
 					dc_Map.dc.DrawCircle(A.x, A.y, 2);
 				}
 			}
+
+			dc_Map.dc.SetPen  (oldPen  );
+			dc_Map.dc.SetBrush(oldBrush);
 		}
 	}
 }
